/*******************************************************************************
* File Name: AFASE.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_AFASE_H) /* Pins AFASE_H */
#define CY_PINS_AFASE_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "AFASE_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 AFASE__PORT == 15 && ((AFASE__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    AFASE_Write(uint8 value);
void    AFASE_SetDriveMode(uint8 mode);
uint8   AFASE_ReadDataReg(void);
uint8   AFASE_Read(void);
void    AFASE_SetInterruptMode(uint16 position, uint16 mode);
uint8   AFASE_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the AFASE_SetDriveMode() function.
     *  @{
     */
        #define AFASE_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define AFASE_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define AFASE_DM_RES_UP          PIN_DM_RES_UP
        #define AFASE_DM_RES_DWN         PIN_DM_RES_DWN
        #define AFASE_DM_OD_LO           PIN_DM_OD_LO
        #define AFASE_DM_OD_HI           PIN_DM_OD_HI
        #define AFASE_DM_STRONG          PIN_DM_STRONG
        #define AFASE_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define AFASE_MASK               AFASE__MASK
#define AFASE_SHIFT              AFASE__SHIFT
#define AFASE_WIDTH              1u

/* Interrupt constants */
#if defined(AFASE__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in AFASE_SetInterruptMode() function.
     *  @{
     */
        #define AFASE_INTR_NONE      (uint16)(0x0000u)
        #define AFASE_INTR_RISING    (uint16)(0x0001u)
        #define AFASE_INTR_FALLING   (uint16)(0x0002u)
        #define AFASE_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define AFASE_INTR_MASK      (0x01u) 
#endif /* (AFASE__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define AFASE_PS                     (* (reg8 *) AFASE__PS)
/* Data Register */
#define AFASE_DR                     (* (reg8 *) AFASE__DR)
/* Port Number */
#define AFASE_PRT_NUM                (* (reg8 *) AFASE__PRT) 
/* Connect to Analog Globals */                                                  
#define AFASE_AG                     (* (reg8 *) AFASE__AG)                       
/* Analog MUX bux enable */
#define AFASE_AMUX                   (* (reg8 *) AFASE__AMUX) 
/* Bidirectional Enable */                                                        
#define AFASE_BIE                    (* (reg8 *) AFASE__BIE)
/* Bit-mask for Aliased Register Access */
#define AFASE_BIT_MASK               (* (reg8 *) AFASE__BIT_MASK)
/* Bypass Enable */
#define AFASE_BYP                    (* (reg8 *) AFASE__BYP)
/* Port wide control signals */                                                   
#define AFASE_CTL                    (* (reg8 *) AFASE__CTL)
/* Drive Modes */
#define AFASE_DM0                    (* (reg8 *) AFASE__DM0) 
#define AFASE_DM1                    (* (reg8 *) AFASE__DM1)
#define AFASE_DM2                    (* (reg8 *) AFASE__DM2) 
/* Input Buffer Disable Override */
#define AFASE_INP_DIS                (* (reg8 *) AFASE__INP_DIS)
/* LCD Common or Segment Drive */
#define AFASE_LCD_COM_SEG            (* (reg8 *) AFASE__LCD_COM_SEG)
/* Enable Segment LCD */
#define AFASE_LCD_EN                 (* (reg8 *) AFASE__LCD_EN)
/* Slew Rate Control */
#define AFASE_SLW                    (* (reg8 *) AFASE__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define AFASE_PRTDSI__CAPS_SEL       (* (reg8 *) AFASE__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define AFASE_PRTDSI__DBL_SYNC_IN    (* (reg8 *) AFASE__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define AFASE_PRTDSI__OE_SEL0        (* (reg8 *) AFASE__PRTDSI__OE_SEL0) 
#define AFASE_PRTDSI__OE_SEL1        (* (reg8 *) AFASE__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define AFASE_PRTDSI__OUT_SEL0       (* (reg8 *) AFASE__PRTDSI__OUT_SEL0) 
#define AFASE_PRTDSI__OUT_SEL1       (* (reg8 *) AFASE__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define AFASE_PRTDSI__SYNC_OUT       (* (reg8 *) AFASE__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(AFASE__SIO_CFG)
    #define AFASE_SIO_HYST_EN        (* (reg8 *) AFASE__SIO_HYST_EN)
    #define AFASE_SIO_REG_HIFREQ     (* (reg8 *) AFASE__SIO_REG_HIFREQ)
    #define AFASE_SIO_CFG            (* (reg8 *) AFASE__SIO_CFG)
    #define AFASE_SIO_DIFF           (* (reg8 *) AFASE__SIO_DIFF)
#endif /* (AFASE__SIO_CFG) */

/* Interrupt Registers */
#if defined(AFASE__INTSTAT)
    #define AFASE_INTSTAT            (* (reg8 *) AFASE__INTSTAT)
    #define AFASE_SNAP               (* (reg8 *) AFASE__SNAP)
    
	#define AFASE_0_INTTYPE_REG 		(* (reg8 *) AFASE__0__INTTYPE)
#endif /* (AFASE__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_AFASE_H */


/* [] END OF FILE */
