/*******************************************************************************
* File Name: AVDC.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_AVDC_H) /* Pins AVDC_H */
#define CY_PINS_AVDC_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "AVDC_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 AVDC__PORT == 15 && ((AVDC__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    AVDC_Write(uint8 value);
void    AVDC_SetDriveMode(uint8 mode);
uint8   AVDC_ReadDataReg(void);
uint8   AVDC_Read(void);
void    AVDC_SetInterruptMode(uint16 position, uint16 mode);
uint8   AVDC_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the AVDC_SetDriveMode() function.
     *  @{
     */
        #define AVDC_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define AVDC_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define AVDC_DM_RES_UP          PIN_DM_RES_UP
        #define AVDC_DM_RES_DWN         PIN_DM_RES_DWN
        #define AVDC_DM_OD_LO           PIN_DM_OD_LO
        #define AVDC_DM_OD_HI           PIN_DM_OD_HI
        #define AVDC_DM_STRONG          PIN_DM_STRONG
        #define AVDC_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define AVDC_MASK               AVDC__MASK
#define AVDC_SHIFT              AVDC__SHIFT
#define AVDC_WIDTH              1u

/* Interrupt constants */
#if defined(AVDC__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in AVDC_SetInterruptMode() function.
     *  @{
     */
        #define AVDC_INTR_NONE      (uint16)(0x0000u)
        #define AVDC_INTR_RISING    (uint16)(0x0001u)
        #define AVDC_INTR_FALLING   (uint16)(0x0002u)
        #define AVDC_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define AVDC_INTR_MASK      (0x01u) 
#endif /* (AVDC__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define AVDC_PS                     (* (reg8 *) AVDC__PS)
/* Data Register */
#define AVDC_DR                     (* (reg8 *) AVDC__DR)
/* Port Number */
#define AVDC_PRT_NUM                (* (reg8 *) AVDC__PRT) 
/* Connect to Analog Globals */                                                  
#define AVDC_AG                     (* (reg8 *) AVDC__AG)                       
/* Analog MUX bux enable */
#define AVDC_AMUX                   (* (reg8 *) AVDC__AMUX) 
/* Bidirectional Enable */                                                        
#define AVDC_BIE                    (* (reg8 *) AVDC__BIE)
/* Bit-mask for Aliased Register Access */
#define AVDC_BIT_MASK               (* (reg8 *) AVDC__BIT_MASK)
/* Bypass Enable */
#define AVDC_BYP                    (* (reg8 *) AVDC__BYP)
/* Port wide control signals */                                                   
#define AVDC_CTL                    (* (reg8 *) AVDC__CTL)
/* Drive Modes */
#define AVDC_DM0                    (* (reg8 *) AVDC__DM0) 
#define AVDC_DM1                    (* (reg8 *) AVDC__DM1)
#define AVDC_DM2                    (* (reg8 *) AVDC__DM2) 
/* Input Buffer Disable Override */
#define AVDC_INP_DIS                (* (reg8 *) AVDC__INP_DIS)
/* LCD Common or Segment Drive */
#define AVDC_LCD_COM_SEG            (* (reg8 *) AVDC__LCD_COM_SEG)
/* Enable Segment LCD */
#define AVDC_LCD_EN                 (* (reg8 *) AVDC__LCD_EN)
/* Slew Rate Control */
#define AVDC_SLW                    (* (reg8 *) AVDC__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define AVDC_PRTDSI__CAPS_SEL       (* (reg8 *) AVDC__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define AVDC_PRTDSI__DBL_SYNC_IN    (* (reg8 *) AVDC__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define AVDC_PRTDSI__OE_SEL0        (* (reg8 *) AVDC__PRTDSI__OE_SEL0) 
#define AVDC_PRTDSI__OE_SEL1        (* (reg8 *) AVDC__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define AVDC_PRTDSI__OUT_SEL0       (* (reg8 *) AVDC__PRTDSI__OUT_SEL0) 
#define AVDC_PRTDSI__OUT_SEL1       (* (reg8 *) AVDC__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define AVDC_PRTDSI__SYNC_OUT       (* (reg8 *) AVDC__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(AVDC__SIO_CFG)
    #define AVDC_SIO_HYST_EN        (* (reg8 *) AVDC__SIO_HYST_EN)
    #define AVDC_SIO_REG_HIFREQ     (* (reg8 *) AVDC__SIO_REG_HIFREQ)
    #define AVDC_SIO_CFG            (* (reg8 *) AVDC__SIO_CFG)
    #define AVDC_SIO_DIFF           (* (reg8 *) AVDC__SIO_DIFF)
#endif /* (AVDC__SIO_CFG) */

/* Interrupt Registers */
#if defined(AVDC__INTSTAT)
    #define AVDC_INTSTAT            (* (reg8 *) AVDC__INTSTAT)
    #define AVDC_SNAP               (* (reg8 *) AVDC__SNAP)
    
	#define AVDC_0_INTTYPE_REG 		(* (reg8 *) AVDC__0__INTTYPE)
#endif /* (AVDC__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_AVDC_H */


/* [] END OF FILE */
