/*******************************************************************************
* File Name: BVDC.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_BVDC_H) /* Pins BVDC_H */
#define CY_PINS_BVDC_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "BVDC_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 BVDC__PORT == 15 && ((BVDC__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    BVDC_Write(uint8 value);
void    BVDC_SetDriveMode(uint8 mode);
uint8   BVDC_ReadDataReg(void);
uint8   BVDC_Read(void);
void    BVDC_SetInterruptMode(uint16 position, uint16 mode);
uint8   BVDC_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the BVDC_SetDriveMode() function.
     *  @{
     */
        #define BVDC_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define BVDC_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define BVDC_DM_RES_UP          PIN_DM_RES_UP
        #define BVDC_DM_RES_DWN         PIN_DM_RES_DWN
        #define BVDC_DM_OD_LO           PIN_DM_OD_LO
        #define BVDC_DM_OD_HI           PIN_DM_OD_HI
        #define BVDC_DM_STRONG          PIN_DM_STRONG
        #define BVDC_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define BVDC_MASK               BVDC__MASK
#define BVDC_SHIFT              BVDC__SHIFT
#define BVDC_WIDTH              1u

/* Interrupt constants */
#if defined(BVDC__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in BVDC_SetInterruptMode() function.
     *  @{
     */
        #define BVDC_INTR_NONE      (uint16)(0x0000u)
        #define BVDC_INTR_RISING    (uint16)(0x0001u)
        #define BVDC_INTR_FALLING   (uint16)(0x0002u)
        #define BVDC_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define BVDC_INTR_MASK      (0x01u) 
#endif /* (BVDC__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define BVDC_PS                     (* (reg8 *) BVDC__PS)
/* Data Register */
#define BVDC_DR                     (* (reg8 *) BVDC__DR)
/* Port Number */
#define BVDC_PRT_NUM                (* (reg8 *) BVDC__PRT) 
/* Connect to Analog Globals */                                                  
#define BVDC_AG                     (* (reg8 *) BVDC__AG)                       
/* Analog MUX bux enable */
#define BVDC_AMUX                   (* (reg8 *) BVDC__AMUX) 
/* Bidirectional Enable */                                                        
#define BVDC_BIE                    (* (reg8 *) BVDC__BIE)
/* Bit-mask for Aliased Register Access */
#define BVDC_BIT_MASK               (* (reg8 *) BVDC__BIT_MASK)
/* Bypass Enable */
#define BVDC_BYP                    (* (reg8 *) BVDC__BYP)
/* Port wide control signals */                                                   
#define BVDC_CTL                    (* (reg8 *) BVDC__CTL)
/* Drive Modes */
#define BVDC_DM0                    (* (reg8 *) BVDC__DM0) 
#define BVDC_DM1                    (* (reg8 *) BVDC__DM1)
#define BVDC_DM2                    (* (reg8 *) BVDC__DM2) 
/* Input Buffer Disable Override */
#define BVDC_INP_DIS                (* (reg8 *) BVDC__INP_DIS)
/* LCD Common or Segment Drive */
#define BVDC_LCD_COM_SEG            (* (reg8 *) BVDC__LCD_COM_SEG)
/* Enable Segment LCD */
#define BVDC_LCD_EN                 (* (reg8 *) BVDC__LCD_EN)
/* Slew Rate Control */
#define BVDC_SLW                    (* (reg8 *) BVDC__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define BVDC_PRTDSI__CAPS_SEL       (* (reg8 *) BVDC__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define BVDC_PRTDSI__DBL_SYNC_IN    (* (reg8 *) BVDC__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define BVDC_PRTDSI__OE_SEL0        (* (reg8 *) BVDC__PRTDSI__OE_SEL0) 
#define BVDC_PRTDSI__OE_SEL1        (* (reg8 *) BVDC__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define BVDC_PRTDSI__OUT_SEL0       (* (reg8 *) BVDC__PRTDSI__OUT_SEL0) 
#define BVDC_PRTDSI__OUT_SEL1       (* (reg8 *) BVDC__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define BVDC_PRTDSI__SYNC_OUT       (* (reg8 *) BVDC__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(BVDC__SIO_CFG)
    #define BVDC_SIO_HYST_EN        (* (reg8 *) BVDC__SIO_HYST_EN)
    #define BVDC_SIO_REG_HIFREQ     (* (reg8 *) BVDC__SIO_REG_HIFREQ)
    #define BVDC_SIO_CFG            (* (reg8 *) BVDC__SIO_CFG)
    #define BVDC_SIO_DIFF           (* (reg8 *) BVDC__SIO_DIFF)
#endif /* (BVDC__SIO_CFG) */

/* Interrupt Registers */
#if defined(BVDC__INTSTAT)
    #define BVDC_INTSTAT            (* (reg8 *) BVDC__INTSTAT)
    #define BVDC_SNAP               (* (reg8 *) BVDC__SNAP)
    
	#define BVDC_0_INTTYPE_REG 		(* (reg8 *) BVDC__0__INTTYPE)
#endif /* (BVDC__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_BVDC_H */


/* [] END OF FILE */
