/*******************************************************************************
* File Name: CFASE.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_CFASE_H) /* Pins CFASE_H */
#define CY_PINS_CFASE_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "CFASE_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 CFASE__PORT == 15 && ((CFASE__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    CFASE_Write(uint8 value);
void    CFASE_SetDriveMode(uint8 mode);
uint8   CFASE_ReadDataReg(void);
uint8   CFASE_Read(void);
void    CFASE_SetInterruptMode(uint16 position, uint16 mode);
uint8   CFASE_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the CFASE_SetDriveMode() function.
     *  @{
     */
        #define CFASE_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define CFASE_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define CFASE_DM_RES_UP          PIN_DM_RES_UP
        #define CFASE_DM_RES_DWN         PIN_DM_RES_DWN
        #define CFASE_DM_OD_LO           PIN_DM_OD_LO
        #define CFASE_DM_OD_HI           PIN_DM_OD_HI
        #define CFASE_DM_STRONG          PIN_DM_STRONG
        #define CFASE_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define CFASE_MASK               CFASE__MASK
#define CFASE_SHIFT              CFASE__SHIFT
#define CFASE_WIDTH              1u

/* Interrupt constants */
#if defined(CFASE__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in CFASE_SetInterruptMode() function.
     *  @{
     */
        #define CFASE_INTR_NONE      (uint16)(0x0000u)
        #define CFASE_INTR_RISING    (uint16)(0x0001u)
        #define CFASE_INTR_FALLING   (uint16)(0x0002u)
        #define CFASE_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define CFASE_INTR_MASK      (0x01u) 
#endif /* (CFASE__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define CFASE_PS                     (* (reg8 *) CFASE__PS)
/* Data Register */
#define CFASE_DR                     (* (reg8 *) CFASE__DR)
/* Port Number */
#define CFASE_PRT_NUM                (* (reg8 *) CFASE__PRT) 
/* Connect to Analog Globals */                                                  
#define CFASE_AG                     (* (reg8 *) CFASE__AG)                       
/* Analog MUX bux enable */
#define CFASE_AMUX                   (* (reg8 *) CFASE__AMUX) 
/* Bidirectional Enable */                                                        
#define CFASE_BIE                    (* (reg8 *) CFASE__BIE)
/* Bit-mask for Aliased Register Access */
#define CFASE_BIT_MASK               (* (reg8 *) CFASE__BIT_MASK)
/* Bypass Enable */
#define CFASE_BYP                    (* (reg8 *) CFASE__BYP)
/* Port wide control signals */                                                   
#define CFASE_CTL                    (* (reg8 *) CFASE__CTL)
/* Drive Modes */
#define CFASE_DM0                    (* (reg8 *) CFASE__DM0) 
#define CFASE_DM1                    (* (reg8 *) CFASE__DM1)
#define CFASE_DM2                    (* (reg8 *) CFASE__DM2) 
/* Input Buffer Disable Override */
#define CFASE_INP_DIS                (* (reg8 *) CFASE__INP_DIS)
/* LCD Common or Segment Drive */
#define CFASE_LCD_COM_SEG            (* (reg8 *) CFASE__LCD_COM_SEG)
/* Enable Segment LCD */
#define CFASE_LCD_EN                 (* (reg8 *) CFASE__LCD_EN)
/* Slew Rate Control */
#define CFASE_SLW                    (* (reg8 *) CFASE__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define CFASE_PRTDSI__CAPS_SEL       (* (reg8 *) CFASE__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define CFASE_PRTDSI__DBL_SYNC_IN    (* (reg8 *) CFASE__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define CFASE_PRTDSI__OE_SEL0        (* (reg8 *) CFASE__PRTDSI__OE_SEL0) 
#define CFASE_PRTDSI__OE_SEL1        (* (reg8 *) CFASE__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define CFASE_PRTDSI__OUT_SEL0       (* (reg8 *) CFASE__PRTDSI__OUT_SEL0) 
#define CFASE_PRTDSI__OUT_SEL1       (* (reg8 *) CFASE__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define CFASE_PRTDSI__SYNC_OUT       (* (reg8 *) CFASE__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(CFASE__SIO_CFG)
    #define CFASE_SIO_HYST_EN        (* (reg8 *) CFASE__SIO_HYST_EN)
    #define CFASE_SIO_REG_HIFREQ     (* (reg8 *) CFASE__SIO_REG_HIFREQ)
    #define CFASE_SIO_CFG            (* (reg8 *) CFASE__SIO_CFG)
    #define CFASE_SIO_DIFF           (* (reg8 *) CFASE__SIO_DIFF)
#endif /* (CFASE__SIO_CFG) */

/* Interrupt Registers */
#if defined(CFASE__INTSTAT)
    #define CFASE_INTSTAT            (* (reg8 *) CFASE__INTSTAT)
    #define CFASE_SNAP               (* (reg8 *) CFASE__SNAP)
    
	#define CFASE_0_INTTYPE_REG 		(* (reg8 *) CFASE__0__INTTYPE)
#endif /* (CFASE__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_CFASE_H */


/* [] END OF FILE */
