/*******************************************************************************
* File Name: CVDC.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_CVDC_H) /* Pins CVDC_H */
#define CY_PINS_CVDC_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "CVDC_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 CVDC__PORT == 15 && ((CVDC__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    CVDC_Write(uint8 value);
void    CVDC_SetDriveMode(uint8 mode);
uint8   CVDC_ReadDataReg(void);
uint8   CVDC_Read(void);
void    CVDC_SetInterruptMode(uint16 position, uint16 mode);
uint8   CVDC_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the CVDC_SetDriveMode() function.
     *  @{
     */
        #define CVDC_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define CVDC_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define CVDC_DM_RES_UP          PIN_DM_RES_UP
        #define CVDC_DM_RES_DWN         PIN_DM_RES_DWN
        #define CVDC_DM_OD_LO           PIN_DM_OD_LO
        #define CVDC_DM_OD_HI           PIN_DM_OD_HI
        #define CVDC_DM_STRONG          PIN_DM_STRONG
        #define CVDC_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define CVDC_MASK               CVDC__MASK
#define CVDC_SHIFT              CVDC__SHIFT
#define CVDC_WIDTH              1u

/* Interrupt constants */
#if defined(CVDC__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in CVDC_SetInterruptMode() function.
     *  @{
     */
        #define CVDC_INTR_NONE      (uint16)(0x0000u)
        #define CVDC_INTR_RISING    (uint16)(0x0001u)
        #define CVDC_INTR_FALLING   (uint16)(0x0002u)
        #define CVDC_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define CVDC_INTR_MASK      (0x01u) 
#endif /* (CVDC__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define CVDC_PS                     (* (reg8 *) CVDC__PS)
/* Data Register */
#define CVDC_DR                     (* (reg8 *) CVDC__DR)
/* Port Number */
#define CVDC_PRT_NUM                (* (reg8 *) CVDC__PRT) 
/* Connect to Analog Globals */                                                  
#define CVDC_AG                     (* (reg8 *) CVDC__AG)                       
/* Analog MUX bux enable */
#define CVDC_AMUX                   (* (reg8 *) CVDC__AMUX) 
/* Bidirectional Enable */                                                        
#define CVDC_BIE                    (* (reg8 *) CVDC__BIE)
/* Bit-mask for Aliased Register Access */
#define CVDC_BIT_MASK               (* (reg8 *) CVDC__BIT_MASK)
/* Bypass Enable */
#define CVDC_BYP                    (* (reg8 *) CVDC__BYP)
/* Port wide control signals */                                                   
#define CVDC_CTL                    (* (reg8 *) CVDC__CTL)
/* Drive Modes */
#define CVDC_DM0                    (* (reg8 *) CVDC__DM0) 
#define CVDC_DM1                    (* (reg8 *) CVDC__DM1)
#define CVDC_DM2                    (* (reg8 *) CVDC__DM2) 
/* Input Buffer Disable Override */
#define CVDC_INP_DIS                (* (reg8 *) CVDC__INP_DIS)
/* LCD Common or Segment Drive */
#define CVDC_LCD_COM_SEG            (* (reg8 *) CVDC__LCD_COM_SEG)
/* Enable Segment LCD */
#define CVDC_LCD_EN                 (* (reg8 *) CVDC__LCD_EN)
/* Slew Rate Control */
#define CVDC_SLW                    (* (reg8 *) CVDC__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define CVDC_PRTDSI__CAPS_SEL       (* (reg8 *) CVDC__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define CVDC_PRTDSI__DBL_SYNC_IN    (* (reg8 *) CVDC__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define CVDC_PRTDSI__OE_SEL0        (* (reg8 *) CVDC__PRTDSI__OE_SEL0) 
#define CVDC_PRTDSI__OE_SEL1        (* (reg8 *) CVDC__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define CVDC_PRTDSI__OUT_SEL0       (* (reg8 *) CVDC__PRTDSI__OUT_SEL0) 
#define CVDC_PRTDSI__OUT_SEL1       (* (reg8 *) CVDC__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define CVDC_PRTDSI__SYNC_OUT       (* (reg8 *) CVDC__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(CVDC__SIO_CFG)
    #define CVDC_SIO_HYST_EN        (* (reg8 *) CVDC__SIO_HYST_EN)
    #define CVDC_SIO_REG_HIFREQ     (* (reg8 *) CVDC__SIO_REG_HIFREQ)
    #define CVDC_SIO_CFG            (* (reg8 *) CVDC__SIO_CFG)
    #define CVDC_SIO_DIFF           (* (reg8 *) CVDC__SIO_DIFF)
#endif /* (CVDC__SIO_CFG) */

/* Interrupt Registers */
#if defined(CVDC__INTSTAT)
    #define CVDC_INTSTAT            (* (reg8 *) CVDC__INTSTAT)
    #define CVDC_SNAP               (* (reg8 *) CVDC__SNAP)
    
	#define CVDC_0_INTTYPE_REG 		(* (reg8 *) CVDC__0__INTTYPE)
#endif /* (CVDC__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_CVDC_H */


/* [] END OF FILE */
