/*******************************************************************************
* File Name: ClearScreenTimer_1_PM.c
* Version 2.70
*
*  Description:
*     This file provides the power management source code to API for the
*     Timer.
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#include "ClearScreenTimer_1.h"

static ClearScreenTimer_1_backupStruct ClearScreenTimer_1_backup;


/*******************************************************************************
* Function Name: ClearScreenTimer_1_SaveConfig
********************************************************************************
*
* Summary:
*     Save the current user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  ClearScreenTimer_1_backup:  Variables of this global structure are modified to
*  store the values of non retention configuration registers when Sleep() API is
*  called.
*
*******************************************************************************/
void ClearScreenTimer_1_SaveConfig(void) 
{
    #if (!ClearScreenTimer_1_UsingFixedFunction)
        ClearScreenTimer_1_backup.TimerUdb = ClearScreenTimer_1_ReadCounter();
        ClearScreenTimer_1_backup.InterruptMaskValue = ClearScreenTimer_1_STATUS_MASK;
        #if (ClearScreenTimer_1_UsingHWCaptureCounter)
            ClearScreenTimer_1_backup.TimerCaptureCounter = ClearScreenTimer_1_ReadCaptureCount();
        #endif /* Back Up capture counter register  */

        #if(!ClearScreenTimer_1_UDB_CONTROL_REG_REMOVED)
            ClearScreenTimer_1_backup.TimerControlRegister = ClearScreenTimer_1_ReadControlRegister();
        #endif /* Backup the enable state of the Timer component */
    #endif /* Backup non retention registers in UDB implementation. All fixed function registers are retention */
}


/*******************************************************************************
* Function Name: ClearScreenTimer_1_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  ClearScreenTimer_1_backup:  Variables of this global structure are used to
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void ClearScreenTimer_1_RestoreConfig(void) 
{   
    #if (!ClearScreenTimer_1_UsingFixedFunction)

        ClearScreenTimer_1_WriteCounter(ClearScreenTimer_1_backup.TimerUdb);
        ClearScreenTimer_1_STATUS_MASK =ClearScreenTimer_1_backup.InterruptMaskValue;
        #if (ClearScreenTimer_1_UsingHWCaptureCounter)
            ClearScreenTimer_1_SetCaptureCount(ClearScreenTimer_1_backup.TimerCaptureCounter);
        #endif /* Restore Capture counter register*/

        #if(!ClearScreenTimer_1_UDB_CONTROL_REG_REMOVED)
            ClearScreenTimer_1_WriteControlRegister(ClearScreenTimer_1_backup.TimerControlRegister);
        #endif /* Restore the enable state of the Timer component */
    #endif /* Restore non retention registers in the UDB implementation only */
}


/*******************************************************************************
* Function Name: ClearScreenTimer_1_Sleep
********************************************************************************
*
* Summary:
*     Stop and Save the user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  ClearScreenTimer_1_backup.TimerEnableState:  Is modified depending on the
*  enable state of the block before entering sleep mode.
*
*******************************************************************************/
void ClearScreenTimer_1_Sleep(void) 
{
    #if(!ClearScreenTimer_1_UDB_CONTROL_REG_REMOVED)
        /* Save Counter's enable state */
        if(ClearScreenTimer_1_CTRL_ENABLE == (ClearScreenTimer_1_CONTROL & ClearScreenTimer_1_CTRL_ENABLE))
        {
            /* Timer is enabled */
            ClearScreenTimer_1_backup.TimerEnableState = 1u;
        }
        else
        {
            /* Timer is disabled */
            ClearScreenTimer_1_backup.TimerEnableState = 0u;
        }
    #endif /* Back up enable state from the Timer control register */
    ClearScreenTimer_1_Stop();
    ClearScreenTimer_1_SaveConfig();
}


/*******************************************************************************
* Function Name: ClearScreenTimer_1_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*
* Parameters:
*  void
*
* Return:
*  void
*
* Global variables:
*  ClearScreenTimer_1_backup.enableState:  Is used to restore the enable state of
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void ClearScreenTimer_1_Wakeup(void) 
{
    ClearScreenTimer_1_RestoreConfig();
    #if(!ClearScreenTimer_1_UDB_CONTROL_REG_REMOVED)
        if(ClearScreenTimer_1_backup.TimerEnableState == 1u)
        {     /* Enable Timer's operation */
                ClearScreenTimer_1_Enable();
        } /* Do nothing if Timer was disabled before */
    #endif /* Remove this code section if Control register is removed */
}


/* [] END OF FILE */
