/*******************************************************************************
* File Name: DVDC.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_DVDC_H) /* Pins DVDC_H */
#define CY_PINS_DVDC_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "DVDC_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 DVDC__PORT == 15 && ((DVDC__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    DVDC_Write(uint8 value);
void    DVDC_SetDriveMode(uint8 mode);
uint8   DVDC_ReadDataReg(void);
uint8   DVDC_Read(void);
void    DVDC_SetInterruptMode(uint16 position, uint16 mode);
uint8   DVDC_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the DVDC_SetDriveMode() function.
     *  @{
     */
        #define DVDC_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define DVDC_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define DVDC_DM_RES_UP          PIN_DM_RES_UP
        #define DVDC_DM_RES_DWN         PIN_DM_RES_DWN
        #define DVDC_DM_OD_LO           PIN_DM_OD_LO
        #define DVDC_DM_OD_HI           PIN_DM_OD_HI
        #define DVDC_DM_STRONG          PIN_DM_STRONG
        #define DVDC_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define DVDC_MASK               DVDC__MASK
#define DVDC_SHIFT              DVDC__SHIFT
#define DVDC_WIDTH              1u

/* Interrupt constants */
#if defined(DVDC__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in DVDC_SetInterruptMode() function.
     *  @{
     */
        #define DVDC_INTR_NONE      (uint16)(0x0000u)
        #define DVDC_INTR_RISING    (uint16)(0x0001u)
        #define DVDC_INTR_FALLING   (uint16)(0x0002u)
        #define DVDC_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define DVDC_INTR_MASK      (0x01u) 
#endif /* (DVDC__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define DVDC_PS                     (* (reg8 *) DVDC__PS)
/* Data Register */
#define DVDC_DR                     (* (reg8 *) DVDC__DR)
/* Port Number */
#define DVDC_PRT_NUM                (* (reg8 *) DVDC__PRT) 
/* Connect to Analog Globals */                                                  
#define DVDC_AG                     (* (reg8 *) DVDC__AG)                       
/* Analog MUX bux enable */
#define DVDC_AMUX                   (* (reg8 *) DVDC__AMUX) 
/* Bidirectional Enable */                                                        
#define DVDC_BIE                    (* (reg8 *) DVDC__BIE)
/* Bit-mask for Aliased Register Access */
#define DVDC_BIT_MASK               (* (reg8 *) DVDC__BIT_MASK)
/* Bypass Enable */
#define DVDC_BYP                    (* (reg8 *) DVDC__BYP)
/* Port wide control signals */                                                   
#define DVDC_CTL                    (* (reg8 *) DVDC__CTL)
/* Drive Modes */
#define DVDC_DM0                    (* (reg8 *) DVDC__DM0) 
#define DVDC_DM1                    (* (reg8 *) DVDC__DM1)
#define DVDC_DM2                    (* (reg8 *) DVDC__DM2) 
/* Input Buffer Disable Override */
#define DVDC_INP_DIS                (* (reg8 *) DVDC__INP_DIS)
/* LCD Common or Segment Drive */
#define DVDC_LCD_COM_SEG            (* (reg8 *) DVDC__LCD_COM_SEG)
/* Enable Segment LCD */
#define DVDC_LCD_EN                 (* (reg8 *) DVDC__LCD_EN)
/* Slew Rate Control */
#define DVDC_SLW                    (* (reg8 *) DVDC__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define DVDC_PRTDSI__CAPS_SEL       (* (reg8 *) DVDC__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define DVDC_PRTDSI__DBL_SYNC_IN    (* (reg8 *) DVDC__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define DVDC_PRTDSI__OE_SEL0        (* (reg8 *) DVDC__PRTDSI__OE_SEL0) 
#define DVDC_PRTDSI__OE_SEL1        (* (reg8 *) DVDC__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define DVDC_PRTDSI__OUT_SEL0       (* (reg8 *) DVDC__PRTDSI__OUT_SEL0) 
#define DVDC_PRTDSI__OUT_SEL1       (* (reg8 *) DVDC__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define DVDC_PRTDSI__SYNC_OUT       (* (reg8 *) DVDC__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(DVDC__SIO_CFG)
    #define DVDC_SIO_HYST_EN        (* (reg8 *) DVDC__SIO_HYST_EN)
    #define DVDC_SIO_REG_HIFREQ     (* (reg8 *) DVDC__SIO_REG_HIFREQ)
    #define DVDC_SIO_CFG            (* (reg8 *) DVDC__SIO_CFG)
    #define DVDC_SIO_DIFF           (* (reg8 *) DVDC__SIO_DIFF)
#endif /* (DVDC__SIO_CFG) */

/* Interrupt Registers */
#if defined(DVDC__INTSTAT)
    #define DVDC_INTSTAT            (* (reg8 *) DVDC__INTSTAT)
    #define DVDC_SNAP               (* (reg8 *) DVDC__SNAP)
    
	#define DVDC_0_INTTYPE_REG 		(* (reg8 *) DVDC__0__INTTYPE)
#endif /* (DVDC__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_DVDC_H */


/* [] END OF FILE */
