/*******************************************************************************
* File Name: FASEPWM_4.h
* Version 3.30
*
* Description:
*  Contains the prototypes and constants for the functions available to the
*  PWM user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_PWM_FASEPWM_4_H)
#define CY_PWM_FASEPWM_4_H

#include "cyfitter.h"
#include "cytypes.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

extern uint8 FASEPWM_4_initVar;


/***************************************
* Conditional Compilation Parameters
***************************************/
#define FASEPWM_4_Resolution                     (8u)
#define FASEPWM_4_UsingFixedFunction             (0u)
#define FASEPWM_4_DeadBandMode                   (0u)
#define FASEPWM_4_KillModeMinTime                (0u)
#define FASEPWM_4_KillMode                       (0u)
#define FASEPWM_4_PWMMode                        (0u)
#define FASEPWM_4_PWMModeIsCenterAligned         (0u)
#define FASEPWM_4_DeadBandUsed                   (0u)
#define FASEPWM_4_DeadBand2_4                    (0u)

#if !defined(FASEPWM_4_PWMUDB_genblk8_stsreg__REMOVED)
    #define FASEPWM_4_UseStatus                  (1u)
#else
    #define FASEPWM_4_UseStatus                  (0u)
#endif /* !defined(FASEPWM_4_PWMUDB_genblk8_stsreg__REMOVED) */

#if !defined(FASEPWM_4_PWMUDB_genblk1_ctrlreg__REMOVED)
    #define FASEPWM_4_UseControl                 (1u)
#else
    #define FASEPWM_4_UseControl                 (0u)
#endif /* !defined(FASEPWM_4_PWMUDB_genblk1_ctrlreg__REMOVED) */

#define FASEPWM_4_UseOneCompareMode              (1u)
#define FASEPWM_4_MinimumKillTime                (1u)
#define FASEPWM_4_EnableMode                     (0u)

#define FASEPWM_4_CompareMode1SW                 (0u)
#define FASEPWM_4_CompareMode2SW                 (0u)

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component PWM_v3_30 requires cy_boot v3.0 or later
#endif /* (CY_ PSOC5LP) */

/* Use Kill Mode Enumerated Types */
#define FASEPWM_4__B_PWM__DISABLED 0
#define FASEPWM_4__B_PWM__ASYNCHRONOUS 1
#define FASEPWM_4__B_PWM__SINGLECYCLE 2
#define FASEPWM_4__B_PWM__LATCHED 3
#define FASEPWM_4__B_PWM__MINTIME 4


/* Use Dead Band Mode Enumerated Types */
#define FASEPWM_4__B_PWM__DBMDISABLED 0
#define FASEPWM_4__B_PWM__DBM_2_4_CLOCKS 1
#define FASEPWM_4__B_PWM__DBM_256_CLOCKS 2


/* Used PWM Mode Enumerated Types */
#define FASEPWM_4__B_PWM__ONE_OUTPUT 0
#define FASEPWM_4__B_PWM__TWO_OUTPUTS 1
#define FASEPWM_4__B_PWM__DUAL_EDGE 2
#define FASEPWM_4__B_PWM__CENTER_ALIGN 3
#define FASEPWM_4__B_PWM__DITHER 5
#define FASEPWM_4__B_PWM__HARDWARESELECT 4


/* Used PWM Compare Mode Enumerated Types */
#define FASEPWM_4__B_PWM__LESS_THAN 1
#define FASEPWM_4__B_PWM__LESS_THAN_OR_EQUAL 2
#define FASEPWM_4__B_PWM__GREATER_THAN 3
#define FASEPWM_4__B_PWM__GREATER_THAN_OR_EQUAL_TO 4
#define FASEPWM_4__B_PWM__EQUAL 0
#define FASEPWM_4__B_PWM__FIRMWARE 5



/***************************************
* Data Struct Definition
***************************************/


/**************************************************************************
 * Sleep Wakeup Backup structure for PWM Component
 *************************************************************************/
typedef struct
{

    uint8 PWMEnableState;

    #if(!FASEPWM_4_UsingFixedFunction)
        uint8 PWMUdb;               /* PWM Current Counter value  */
        #if(!FASEPWM_4_PWMModeIsCenterAligned)
            uint8 PWMPeriod;
        #endif /* (!FASEPWM_4_PWMModeIsCenterAligned) */
        #if (FASEPWM_4_UseStatus)
            uint8 InterruptMaskValue;   /* PWM Current Interrupt Mask */
        #endif /* (FASEPWM_4_UseStatus) */

        /* Backup for Deadband parameters */
        #if(FASEPWM_4_DeadBandMode == FASEPWM_4__B_PWM__DBM_256_CLOCKS || \
            FASEPWM_4_DeadBandMode == FASEPWM_4__B_PWM__DBM_2_4_CLOCKS)
            uint8 PWMdeadBandValue; /* Dead Band Counter Current Value */
        #endif /* deadband count is either 2-4 clocks or 256 clocks */

        /* Backup Kill Mode Counter*/
        #if(FASEPWM_4_KillModeMinTime)
            uint8 PWMKillCounterPeriod; /* Kill Mode period value */
        #endif /* (FASEPWM_4_KillModeMinTime) */

        /* Backup control register */
        #if(FASEPWM_4_UseControl)
            uint8 PWMControlRegister; /* PWM Control Register value */
        #endif /* (FASEPWM_4_UseControl) */

    #endif /* (!FASEPWM_4_UsingFixedFunction) */

}FASEPWM_4_backupStruct;


/***************************************
*        Function Prototypes
 **************************************/

void    FASEPWM_4_Start(void) ;
void    FASEPWM_4_Stop(void) ;

#if (FASEPWM_4_UseStatus || FASEPWM_4_UsingFixedFunction)
    void  FASEPWM_4_SetInterruptMode(uint8 interruptMode) ;
    uint8 FASEPWM_4_ReadStatusRegister(void) ;
#endif /* (FASEPWM_4_UseStatus || FASEPWM_4_UsingFixedFunction) */

#define FASEPWM_4_GetInterruptSource() FASEPWM_4_ReadStatusRegister()

#if (FASEPWM_4_UseControl)
    uint8 FASEPWM_4_ReadControlRegister(void) ;
    void  FASEPWM_4_WriteControlRegister(uint8 control)
          ;
#endif /* (FASEPWM_4_UseControl) */

#if (FASEPWM_4_UseOneCompareMode)
   #if (FASEPWM_4_CompareMode1SW)
       void    FASEPWM_4_SetCompareMode(uint8 comparemode)
               ;
   #endif /* (FASEPWM_4_CompareMode1SW) */
#else
    #if (FASEPWM_4_CompareMode1SW)
        void    FASEPWM_4_SetCompareMode1(uint8 comparemode)
                ;
    #endif /* (FASEPWM_4_CompareMode1SW) */
    #if (FASEPWM_4_CompareMode2SW)
        void    FASEPWM_4_SetCompareMode2(uint8 comparemode)
                ;
    #endif /* (FASEPWM_4_CompareMode2SW) */
#endif /* (FASEPWM_4_UseOneCompareMode) */

#if (!FASEPWM_4_UsingFixedFunction)
    uint8   FASEPWM_4_ReadCounter(void) ;
    uint8 FASEPWM_4_ReadCapture(void) ;

    #if (FASEPWM_4_UseStatus)
            void FASEPWM_4_ClearFIFO(void) ;
    #endif /* (FASEPWM_4_UseStatus) */

    void    FASEPWM_4_WriteCounter(uint8 counter)
            ;
#endif /* (!FASEPWM_4_UsingFixedFunction) */

void    FASEPWM_4_WritePeriod(uint8 period)
        ;
uint8 FASEPWM_4_ReadPeriod(void) ;

#if (FASEPWM_4_UseOneCompareMode)
    void    FASEPWM_4_WriteCompare(uint8 compare)
            ;
    uint8 FASEPWM_4_ReadCompare(void) ;
#else
    void    FASEPWM_4_WriteCompare1(uint8 compare)
            ;
    uint8 FASEPWM_4_ReadCompare1(void) ;
    void    FASEPWM_4_WriteCompare2(uint8 compare)
            ;
    uint8 FASEPWM_4_ReadCompare2(void) ;
#endif /* (FASEPWM_4_UseOneCompareMode) */


#if (FASEPWM_4_DeadBandUsed)
    void    FASEPWM_4_WriteDeadTime(uint8 deadtime) ;
    uint8   FASEPWM_4_ReadDeadTime(void) ;
#endif /* (FASEPWM_4_DeadBandUsed) */

#if ( FASEPWM_4_KillModeMinTime)
    void FASEPWM_4_WriteKillTime(uint8 killtime) ;
    uint8 FASEPWM_4_ReadKillTime(void) ;
#endif /* ( FASEPWM_4_KillModeMinTime) */

void FASEPWM_4_Init(void) ;
void FASEPWM_4_Enable(void) ;
void FASEPWM_4_Sleep(void) ;
void FASEPWM_4_Wakeup(void) ;
void FASEPWM_4_SaveConfig(void) ;
void FASEPWM_4_RestoreConfig(void) ;


/***************************************
*         Initialization Values
**************************************/
#define FASEPWM_4_INIT_PERIOD_VALUE          (255u)
#define FASEPWM_4_INIT_COMPARE_VALUE1        (127u)
#define FASEPWM_4_INIT_COMPARE_VALUE2        (63u)
#define FASEPWM_4_INIT_INTERRUPTS_MODE       (uint8)(((uint8)(0u <<   \
                                                    FASEPWM_4_STATUS_TC_INT_EN_MASK_SHIFT)) | \
                                                    (uint8)((uint8)(0u <<  \
                                                    FASEPWM_4_STATUS_CMP2_INT_EN_MASK_SHIFT)) | \
                                                    (uint8)((uint8)(0u <<  \
                                                    FASEPWM_4_STATUS_CMP1_INT_EN_MASK_SHIFT )) | \
                                                    (uint8)((uint8)(0u <<  \
                                                    FASEPWM_4_STATUS_KILL_INT_EN_MASK_SHIFT )))
#define FASEPWM_4_DEFAULT_COMPARE2_MODE      (uint8)((uint8)1u <<  FASEPWM_4_CTRL_CMPMODE2_SHIFT)
#define FASEPWM_4_DEFAULT_COMPARE1_MODE      (uint8)((uint8)1u <<  FASEPWM_4_CTRL_CMPMODE1_SHIFT)
#define FASEPWM_4_INIT_DEAD_TIME             (1u)


/********************************
*         Registers
******************************** */

#if (FASEPWM_4_UsingFixedFunction)
   #define FASEPWM_4_PERIOD_LSB              (*(reg16 *) FASEPWM_4_PWMHW__PER0)
   #define FASEPWM_4_PERIOD_LSB_PTR          ( (reg16 *) FASEPWM_4_PWMHW__PER0)
   #define FASEPWM_4_COMPARE1_LSB            (*(reg16 *) FASEPWM_4_PWMHW__CNT_CMP0)
   #define FASEPWM_4_COMPARE1_LSB_PTR        ( (reg16 *) FASEPWM_4_PWMHW__CNT_CMP0)
   #define FASEPWM_4_COMPARE2_LSB            (0x00u)
   #define FASEPWM_4_COMPARE2_LSB_PTR        (0x00u)
   #define FASEPWM_4_COUNTER_LSB             (*(reg16 *) FASEPWM_4_PWMHW__CNT_CMP0)
   #define FASEPWM_4_COUNTER_LSB_PTR         ( (reg16 *) FASEPWM_4_PWMHW__CNT_CMP0)
   #define FASEPWM_4_CAPTURE_LSB             (*(reg16 *) FASEPWM_4_PWMHW__CAP0)
   #define FASEPWM_4_CAPTURE_LSB_PTR         ( (reg16 *) FASEPWM_4_PWMHW__CAP0)
   #define FASEPWM_4_RT1                     (*(reg8 *)  FASEPWM_4_PWMHW__RT1)
   #define FASEPWM_4_RT1_PTR                 ( (reg8 *)  FASEPWM_4_PWMHW__RT1)

#else
   #if (FASEPWM_4_Resolution == 8u) /* 8bit - PWM */

       #if(FASEPWM_4_PWMModeIsCenterAligned)
           #define FASEPWM_4_PERIOD_LSB      (*(reg8 *)  FASEPWM_4_PWMUDB_sP8_pwmdp_u0__D1_REG)
           #define FASEPWM_4_PERIOD_LSB_PTR  ((reg8 *)   FASEPWM_4_PWMUDB_sP8_pwmdp_u0__D1_REG)
       #else
           #define FASEPWM_4_PERIOD_LSB      (*(reg8 *)  FASEPWM_4_PWMUDB_sP8_pwmdp_u0__F0_REG)
           #define FASEPWM_4_PERIOD_LSB_PTR  ((reg8 *)   FASEPWM_4_PWMUDB_sP8_pwmdp_u0__F0_REG)
       #endif /* (FASEPWM_4_PWMModeIsCenterAligned) */

       #define FASEPWM_4_COMPARE1_LSB        (*(reg8 *)  FASEPWM_4_PWMUDB_sP8_pwmdp_u0__D0_REG)
       #define FASEPWM_4_COMPARE1_LSB_PTR    ((reg8 *)   FASEPWM_4_PWMUDB_sP8_pwmdp_u0__D0_REG)
       #define FASEPWM_4_COMPARE2_LSB        (*(reg8 *)  FASEPWM_4_PWMUDB_sP8_pwmdp_u0__D1_REG)
       #define FASEPWM_4_COMPARE2_LSB_PTR    ((reg8 *)   FASEPWM_4_PWMUDB_sP8_pwmdp_u0__D1_REG)
       #define FASEPWM_4_COUNTERCAP_LSB      (*(reg8 *)  FASEPWM_4_PWMUDB_sP8_pwmdp_u0__A1_REG)
       #define FASEPWM_4_COUNTERCAP_LSB_PTR  ((reg8 *)   FASEPWM_4_PWMUDB_sP8_pwmdp_u0__A1_REG)
       #define FASEPWM_4_COUNTER_LSB         (*(reg8 *)  FASEPWM_4_PWMUDB_sP8_pwmdp_u0__A0_REG)
       #define FASEPWM_4_COUNTER_LSB_PTR     ((reg8 *)   FASEPWM_4_PWMUDB_sP8_pwmdp_u0__A0_REG)
       #define FASEPWM_4_CAPTURE_LSB         (*(reg8 *)  FASEPWM_4_PWMUDB_sP8_pwmdp_u0__F1_REG)
       #define FASEPWM_4_CAPTURE_LSB_PTR     ((reg8 *)   FASEPWM_4_PWMUDB_sP8_pwmdp_u0__F1_REG)

   #else
        #if(CY_PSOC3) /* 8-bit address space */
            #if(FASEPWM_4_PWMModeIsCenterAligned)
               #define FASEPWM_4_PERIOD_LSB      (*(reg16 *) FASEPWM_4_PWMUDB_sP8_pwmdp_u0__D1_REG)
               #define FASEPWM_4_PERIOD_LSB_PTR  ((reg16 *)  FASEPWM_4_PWMUDB_sP8_pwmdp_u0__D1_REG)
            #else
               #define FASEPWM_4_PERIOD_LSB      (*(reg16 *) FASEPWM_4_PWMUDB_sP8_pwmdp_u0__F0_REG)
               #define FASEPWM_4_PERIOD_LSB_PTR  ((reg16 *)  FASEPWM_4_PWMUDB_sP8_pwmdp_u0__F0_REG)
            #endif /* (FASEPWM_4_PWMModeIsCenterAligned) */

            #define FASEPWM_4_COMPARE1_LSB       (*(reg16 *) FASEPWM_4_PWMUDB_sP8_pwmdp_u0__D0_REG)
            #define FASEPWM_4_COMPARE1_LSB_PTR   ((reg16 *)  FASEPWM_4_PWMUDB_sP8_pwmdp_u0__D0_REG)
            #define FASEPWM_4_COMPARE2_LSB       (*(reg16 *) FASEPWM_4_PWMUDB_sP8_pwmdp_u0__D1_REG)
            #define FASEPWM_4_COMPARE2_LSB_PTR   ((reg16 *)  FASEPWM_4_PWMUDB_sP8_pwmdp_u0__D1_REG)
            #define FASEPWM_4_COUNTERCAP_LSB     (*(reg16 *) FASEPWM_4_PWMUDB_sP8_pwmdp_u0__A1_REG)
            #define FASEPWM_4_COUNTERCAP_LSB_PTR ((reg16 *)  FASEPWM_4_PWMUDB_sP8_pwmdp_u0__A1_REG)
            #define FASEPWM_4_COUNTER_LSB        (*(reg16 *) FASEPWM_4_PWMUDB_sP8_pwmdp_u0__A0_REG)
            #define FASEPWM_4_COUNTER_LSB_PTR    ((reg16 *)  FASEPWM_4_PWMUDB_sP8_pwmdp_u0__A0_REG)
            #define FASEPWM_4_CAPTURE_LSB        (*(reg16 *) FASEPWM_4_PWMUDB_sP8_pwmdp_u0__F1_REG)
            #define FASEPWM_4_CAPTURE_LSB_PTR    ((reg16 *)  FASEPWM_4_PWMUDB_sP8_pwmdp_u0__F1_REG)
        #else
            #if(FASEPWM_4_PWMModeIsCenterAligned)
               #define FASEPWM_4_PERIOD_LSB      (*(reg16 *) FASEPWM_4_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
               #define FASEPWM_4_PERIOD_LSB_PTR  ((reg16 *)  FASEPWM_4_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
            #else
               #define FASEPWM_4_PERIOD_LSB      (*(reg16 *) FASEPWM_4_PWMUDB_sP8_pwmdp_u0__16BIT_F0_REG)
               #define FASEPWM_4_PERIOD_LSB_PTR  ((reg16 *)  FASEPWM_4_PWMUDB_sP8_pwmdp_u0__16BIT_F0_REG)
            #endif /* (FASEPWM_4_PWMModeIsCenterAligned) */

            #define FASEPWM_4_COMPARE1_LSB       (*(reg16 *) FASEPWM_4_PWMUDB_sP8_pwmdp_u0__16BIT_D0_REG)
            #define FASEPWM_4_COMPARE1_LSB_PTR   ((reg16 *)  FASEPWM_4_PWMUDB_sP8_pwmdp_u0__16BIT_D0_REG)
            #define FASEPWM_4_COMPARE2_LSB       (*(reg16 *) FASEPWM_4_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
            #define FASEPWM_4_COMPARE2_LSB_PTR   ((reg16 *)  FASEPWM_4_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
            #define FASEPWM_4_COUNTERCAP_LSB     (*(reg16 *) FASEPWM_4_PWMUDB_sP8_pwmdp_u0__16BIT_A1_REG)
            #define FASEPWM_4_COUNTERCAP_LSB_PTR ((reg16 *)  FASEPWM_4_PWMUDB_sP8_pwmdp_u0__16BIT_A1_REG)
            #define FASEPWM_4_COUNTER_LSB        (*(reg16 *) FASEPWM_4_PWMUDB_sP8_pwmdp_u0__16BIT_A0_REG)
            #define FASEPWM_4_COUNTER_LSB_PTR    ((reg16 *)  FASEPWM_4_PWMUDB_sP8_pwmdp_u0__16BIT_A0_REG)
            #define FASEPWM_4_CAPTURE_LSB        (*(reg16 *) FASEPWM_4_PWMUDB_sP8_pwmdp_u0__16BIT_F1_REG)
            #define FASEPWM_4_CAPTURE_LSB_PTR    ((reg16 *)  FASEPWM_4_PWMUDB_sP8_pwmdp_u0__16BIT_F1_REG)
        #endif /* (CY_PSOC3) */

       #define FASEPWM_4_AUX_CONTROLDP1          (*(reg8 *)  FASEPWM_4_PWMUDB_sP8_pwmdp_u1__DP_AUX_CTL_REG)
       #define FASEPWM_4_AUX_CONTROLDP1_PTR      ((reg8 *)   FASEPWM_4_PWMUDB_sP8_pwmdp_u1__DP_AUX_CTL_REG)

   #endif /* (FASEPWM_4_Resolution == 8) */

   #define FASEPWM_4_COUNTERCAP_LSB_PTR_8BIT ( (reg8 *)  FASEPWM_4_PWMUDB_sP8_pwmdp_u0__A1_REG)
   #define FASEPWM_4_AUX_CONTROLDP0          (*(reg8 *)  FASEPWM_4_PWMUDB_sP8_pwmdp_u0__DP_AUX_CTL_REG)
   #define FASEPWM_4_AUX_CONTROLDP0_PTR      ((reg8 *)   FASEPWM_4_PWMUDB_sP8_pwmdp_u0__DP_AUX_CTL_REG)

#endif /* (FASEPWM_4_UsingFixedFunction) */

#if(FASEPWM_4_KillModeMinTime )
    #define FASEPWM_4_KILLMODEMINTIME        (*(reg8 *)  FASEPWM_4_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    #define FASEPWM_4_KILLMODEMINTIME_PTR    ((reg8 *)   FASEPWM_4_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    /* Fixed Function Block has no Kill Mode parameters because it is Asynchronous only */
#endif /* (FASEPWM_4_KillModeMinTime ) */

#if(FASEPWM_4_DeadBandMode == FASEPWM_4__B_PWM__DBM_256_CLOCKS)
    #define FASEPWM_4_DEADBAND_COUNT         (*(reg8 *)  FASEPWM_4_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define FASEPWM_4_DEADBAND_COUNT_PTR     ((reg8 *)   FASEPWM_4_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define FASEPWM_4_DEADBAND_LSB_PTR       ((reg8 *)   FASEPWM_4_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
    #define FASEPWM_4_DEADBAND_LSB           (*(reg8 *)  FASEPWM_4_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
#elif(FASEPWM_4_DeadBandMode == FASEPWM_4__B_PWM__DBM_2_4_CLOCKS)
    
    /* In Fixed Function Block these bits are in the control blocks control register */
    #if (FASEPWM_4_UsingFixedFunction)
        #define FASEPWM_4_DEADBAND_COUNT         (*(reg8 *)  FASEPWM_4_PWMHW__CFG0)
        #define FASEPWM_4_DEADBAND_COUNT_PTR     ((reg8 *)   FASEPWM_4_PWMHW__CFG0)
        #define FASEPWM_4_DEADBAND_COUNT_MASK    (uint8)((uint8)0x03u << FASEPWM_4_DEADBAND_COUNT_SHIFT)

        /* As defined by the Register Map as DEADBAND_PERIOD[1:0] in CFG0 */
        #define FASEPWM_4_DEADBAND_COUNT_SHIFT   (0x06u)
    #else
        /* Lower two bits of the added control register define the count 1-3 */
        #define FASEPWM_4_DEADBAND_COUNT         (*(reg8 *)  FASEPWM_4_PWMUDB_genblk7_dbctrlreg__CONTROL_REG)
        #define FASEPWM_4_DEADBAND_COUNT_PTR     ((reg8 *)   FASEPWM_4_PWMUDB_genblk7_dbctrlreg__CONTROL_REG)
        #define FASEPWM_4_DEADBAND_COUNT_MASK    (uint8)((uint8)0x03u << FASEPWM_4_DEADBAND_COUNT_SHIFT)

        /* As defined by the verilog implementation of the Control Register */
        #define FASEPWM_4_DEADBAND_COUNT_SHIFT   (0x00u)
    #endif /* (FASEPWM_4_UsingFixedFunction) */
#endif /* (FASEPWM_4_DeadBandMode == FASEPWM_4__B_PWM__DBM_256_CLOCKS) */



#if (FASEPWM_4_UsingFixedFunction)
    #define FASEPWM_4_STATUS                 (*(reg8 *) FASEPWM_4_PWMHW__SR0)
    #define FASEPWM_4_STATUS_PTR             ((reg8 *) FASEPWM_4_PWMHW__SR0)
    #define FASEPWM_4_STATUS_MASK            (*(reg8 *) FASEPWM_4_PWMHW__SR0)
    #define FASEPWM_4_STATUS_MASK_PTR        ((reg8 *) FASEPWM_4_PWMHW__SR0)
    #define FASEPWM_4_CONTROL                (*(reg8 *) FASEPWM_4_PWMHW__CFG0)
    #define FASEPWM_4_CONTROL_PTR            ((reg8 *) FASEPWM_4_PWMHW__CFG0)
    #define FASEPWM_4_CONTROL2               (*(reg8 *) FASEPWM_4_PWMHW__CFG1)
    #define FASEPWM_4_CONTROL3               (*(reg8 *) FASEPWM_4_PWMHW__CFG2)
    #define FASEPWM_4_GLOBAL_ENABLE          (*(reg8 *) FASEPWM_4_PWMHW__PM_ACT_CFG)
    #define FASEPWM_4_GLOBAL_ENABLE_PTR      ( (reg8 *) FASEPWM_4_PWMHW__PM_ACT_CFG)
    #define FASEPWM_4_GLOBAL_STBY_ENABLE     (*(reg8 *) FASEPWM_4_PWMHW__PM_STBY_CFG)
    #define FASEPWM_4_GLOBAL_STBY_ENABLE_PTR ( (reg8 *) FASEPWM_4_PWMHW__PM_STBY_CFG)


    /***********************************
    *          Constants
    ***********************************/

    /* Fixed Function Block Chosen */
    #define FASEPWM_4_BLOCK_EN_MASK          (FASEPWM_4_PWMHW__PM_ACT_MSK)
    #define FASEPWM_4_BLOCK_STBY_EN_MASK     (FASEPWM_4_PWMHW__PM_STBY_MSK)
    
    /* Control Register definitions */
    #define FASEPWM_4_CTRL_ENABLE_SHIFT      (0x00u)

    /* As defined by Register map as MODE_CFG bits in CFG2*/
    #define FASEPWM_4_CTRL_CMPMODE1_SHIFT    (0x04u)

    /* As defined by Register map */
    #define FASEPWM_4_CTRL_DEAD_TIME_SHIFT   (0x06u)  

    /* Fixed Function Block Only CFG register bit definitions */
    /*  Set to compare mode */
    #define FASEPWM_4_CFG0_MODE              (0x02u)   

    /* Enable the block to run */
    #define FASEPWM_4_CFG0_ENABLE            (0x01u)   
    
    /* As defined by Register map as DB bit in CFG0 */
    #define FASEPWM_4_CFG0_DB                (0x20u)   

    /* Control Register Bit Masks */
    #define FASEPWM_4_CTRL_ENABLE            (uint8)((uint8)0x01u << FASEPWM_4_CTRL_ENABLE_SHIFT)
    #define FASEPWM_4_CTRL_RESET             (uint8)((uint8)0x01u << FASEPWM_4_CTRL_RESET_SHIFT)
    #define FASEPWM_4_CTRL_CMPMODE2_MASK     (uint8)((uint8)0x07u << FASEPWM_4_CTRL_CMPMODE2_SHIFT)
    #define FASEPWM_4_CTRL_CMPMODE1_MASK     (uint8)((uint8)0x07u << FASEPWM_4_CTRL_CMPMODE1_SHIFT)

    /* Control2 Register Bit Masks */
    /* As defined in Register Map, Part of the TMRX_CFG1 register */
    #define FASEPWM_4_CTRL2_IRQ_SEL_SHIFT    (0x00u)
    #define FASEPWM_4_CTRL2_IRQ_SEL          (uint8)((uint8)0x01u << FASEPWM_4_CTRL2_IRQ_SEL_SHIFT)

    /* Status Register Bit Locations */
    /* As defined by Register map as TC in SR0 */
    #define FASEPWM_4_STATUS_TC_SHIFT        (0x07u)   
    
    /* As defined by the Register map as CAP_CMP in SR0 */
    #define FASEPWM_4_STATUS_CMP1_SHIFT      (0x06u)   

    /* Status Register Interrupt Enable Bit Locations */
    #define FASEPWM_4_STATUS_KILL_INT_EN_MASK_SHIFT          (0x00u)
    #define FASEPWM_4_STATUS_TC_INT_EN_MASK_SHIFT            (FASEPWM_4_STATUS_TC_SHIFT - 4u)
    #define FASEPWM_4_STATUS_CMP2_INT_EN_MASK_SHIFT          (0x00u)
    #define FASEPWM_4_STATUS_CMP1_INT_EN_MASK_SHIFT          (FASEPWM_4_STATUS_CMP1_SHIFT - 4u)

    /* Status Register Bit Masks */
    #define FASEPWM_4_STATUS_TC              (uint8)((uint8)0x01u << FASEPWM_4_STATUS_TC_SHIFT)
    #define FASEPWM_4_STATUS_CMP1            (uint8)((uint8)0x01u << FASEPWM_4_STATUS_CMP1_SHIFT)

    /* Status Register Interrupt Bit Masks */
    #define FASEPWM_4_STATUS_TC_INT_EN_MASK              (uint8)((uint8)FASEPWM_4_STATUS_TC >> 4u)
    #define FASEPWM_4_STATUS_CMP1_INT_EN_MASK            (uint8)((uint8)FASEPWM_4_STATUS_CMP1 >> 4u)

    /*RT1 Synch Constants */
    #define FASEPWM_4_RT1_SHIFT             (0x04u)

    /* Sync TC and CMP bit masks */
    #define FASEPWM_4_RT1_MASK              (uint8)((uint8)0x03u << FASEPWM_4_RT1_SHIFT)
    #define FASEPWM_4_SYNC                  (uint8)((uint8)0x03u << FASEPWM_4_RT1_SHIFT)
    #define FASEPWM_4_SYNCDSI_SHIFT         (0x00u)

    /* Sync all DSI inputs */
    #define FASEPWM_4_SYNCDSI_MASK          (uint8)((uint8)0x0Fu << FASEPWM_4_SYNCDSI_SHIFT)

    /* Sync all DSI inputs */
    #define FASEPWM_4_SYNCDSI_EN            (uint8)((uint8)0x0Fu << FASEPWM_4_SYNCDSI_SHIFT)


#else
    #define FASEPWM_4_STATUS                (*(reg8 *)   FASEPWM_4_PWMUDB_genblk8_stsreg__STATUS_REG )
    #define FASEPWM_4_STATUS_PTR            ((reg8 *)    FASEPWM_4_PWMUDB_genblk8_stsreg__STATUS_REG )
    #define FASEPWM_4_STATUS_MASK           (*(reg8 *)   FASEPWM_4_PWMUDB_genblk8_stsreg__MASK_REG)
    #define FASEPWM_4_STATUS_MASK_PTR       ((reg8 *)    FASEPWM_4_PWMUDB_genblk8_stsreg__MASK_REG)
    #define FASEPWM_4_STATUS_AUX_CTRL       (*(reg8 *)   FASEPWM_4_PWMUDB_genblk8_stsreg__STATUS_AUX_CTL_REG)
    #define FASEPWM_4_CONTROL               (*(reg8 *)   FASEPWM_4_PWMUDB_genblk1_ctrlreg__CONTROL_REG)
    #define FASEPWM_4_CONTROL_PTR           ((reg8 *)    FASEPWM_4_PWMUDB_genblk1_ctrlreg__CONTROL_REG)


    /***********************************
    *          Constants
    ***********************************/

    /* Control Register bit definitions */
    #define FASEPWM_4_CTRL_ENABLE_SHIFT      (0x07u)
    #define FASEPWM_4_CTRL_RESET_SHIFT       (0x06u)
    #define FASEPWM_4_CTRL_CMPMODE2_SHIFT    (0x03u)
    #define FASEPWM_4_CTRL_CMPMODE1_SHIFT    (0x00u)
    #define FASEPWM_4_CTRL_DEAD_TIME_SHIFT   (0x00u)   /* No Shift Needed for UDB block */
    
    /* Control Register Bit Masks */
    #define FASEPWM_4_CTRL_ENABLE            (uint8)((uint8)0x01u << FASEPWM_4_CTRL_ENABLE_SHIFT)
    #define FASEPWM_4_CTRL_RESET             (uint8)((uint8)0x01u << FASEPWM_4_CTRL_RESET_SHIFT)
    #define FASEPWM_4_CTRL_CMPMODE2_MASK     (uint8)((uint8)0x07u << FASEPWM_4_CTRL_CMPMODE2_SHIFT)
    #define FASEPWM_4_CTRL_CMPMODE1_MASK     (uint8)((uint8)0x07u << FASEPWM_4_CTRL_CMPMODE1_SHIFT)

    /* Status Register Bit Locations */
    #define FASEPWM_4_STATUS_KILL_SHIFT          (0x05u)
    #define FASEPWM_4_STATUS_FIFONEMPTY_SHIFT    (0x04u)
    #define FASEPWM_4_STATUS_FIFOFULL_SHIFT      (0x03u)
    #define FASEPWM_4_STATUS_TC_SHIFT            (0x02u)
    #define FASEPWM_4_STATUS_CMP2_SHIFT          (0x01u)
    #define FASEPWM_4_STATUS_CMP1_SHIFT          (0x00u)

    /* Status Register Interrupt Enable Bit Locations - UDB Status Interrupt Mask match Status Bit Locations*/
    #define FASEPWM_4_STATUS_KILL_INT_EN_MASK_SHIFT          (FASEPWM_4_STATUS_KILL_SHIFT)
    #define FASEPWM_4_STATUS_FIFONEMPTY_INT_EN_MASK_SHIFT    (FASEPWM_4_STATUS_FIFONEMPTY_SHIFT)
    #define FASEPWM_4_STATUS_FIFOFULL_INT_EN_MASK_SHIFT      (FASEPWM_4_STATUS_FIFOFULL_SHIFT)
    #define FASEPWM_4_STATUS_TC_INT_EN_MASK_SHIFT            (FASEPWM_4_STATUS_TC_SHIFT)
    #define FASEPWM_4_STATUS_CMP2_INT_EN_MASK_SHIFT          (FASEPWM_4_STATUS_CMP2_SHIFT)
    #define FASEPWM_4_STATUS_CMP1_INT_EN_MASK_SHIFT          (FASEPWM_4_STATUS_CMP1_SHIFT)

    /* Status Register Bit Masks */
    #define FASEPWM_4_STATUS_KILL            (uint8)((uint8)0x00u << FASEPWM_4_STATUS_KILL_SHIFT )
    #define FASEPWM_4_STATUS_FIFOFULL        (uint8)((uint8)0x01u << FASEPWM_4_STATUS_FIFOFULL_SHIFT)
    #define FASEPWM_4_STATUS_FIFONEMPTY      (uint8)((uint8)0x01u << FASEPWM_4_STATUS_FIFONEMPTY_SHIFT)
    #define FASEPWM_4_STATUS_TC              (uint8)((uint8)0x01u << FASEPWM_4_STATUS_TC_SHIFT)
    #define FASEPWM_4_STATUS_CMP2            (uint8)((uint8)0x01u << FASEPWM_4_STATUS_CMP2_SHIFT)
    #define FASEPWM_4_STATUS_CMP1            (uint8)((uint8)0x01u << FASEPWM_4_STATUS_CMP1_SHIFT)

    /* Status Register Interrupt Bit Masks  - UDB Status Interrupt Mask match Status Bit Locations */
    #define FASEPWM_4_STATUS_KILL_INT_EN_MASK            (FASEPWM_4_STATUS_KILL)
    #define FASEPWM_4_STATUS_FIFOFULL_INT_EN_MASK        (FASEPWM_4_STATUS_FIFOFULL)
    #define FASEPWM_4_STATUS_FIFONEMPTY_INT_EN_MASK      (FASEPWM_4_STATUS_FIFONEMPTY)
    #define FASEPWM_4_STATUS_TC_INT_EN_MASK              (FASEPWM_4_STATUS_TC)
    #define FASEPWM_4_STATUS_CMP2_INT_EN_MASK            (FASEPWM_4_STATUS_CMP2)
    #define FASEPWM_4_STATUS_CMP1_INT_EN_MASK            (FASEPWM_4_STATUS_CMP1)

    /* Datapath Auxillary Control Register bit definitions */
    #define FASEPWM_4_AUX_CTRL_FIFO0_CLR         (0x01u)
    #define FASEPWM_4_AUX_CTRL_FIFO1_CLR         (0x02u)
    #define FASEPWM_4_AUX_CTRL_FIFO0_LVL         (0x04u)
    #define FASEPWM_4_AUX_CTRL_FIFO1_LVL         (0x08u)
    #define FASEPWM_4_STATUS_ACTL_INT_EN_MASK    (0x10u) /* As defined for the ACTL Register */
#endif /* FASEPWM_4_UsingFixedFunction */

#endif  /* CY_PWM_FASEPWM_4_H */


/* [] END OF FILE */
