/*******************************************************************************
* File Name: InactivityTimer.h
* Version 2.70
*
*  Description:
*     Contains the function prototypes and constants available to the timer
*     user module.
*
*   Note:
*     None
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_Timer_v2_60_InactivityTimer_H)
#define CY_Timer_v2_60_InactivityTimer_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

extern uint8 InactivityTimer_initVar;

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component Timer_v2_70 requires cy_boot v3.0 or later
#endif /* (CY_ PSOC5LP) */


/**************************************
*           Parameter Defaults
**************************************/

#define InactivityTimer_Resolution                 16u
#define InactivityTimer_UsingFixedFunction         0u
#define InactivityTimer_UsingHWCaptureCounter      0u
#define InactivityTimer_SoftwareCaptureMode        0u
#define InactivityTimer_SoftwareTriggerMode        0u
#define InactivityTimer_UsingHWEnable              0u
#define InactivityTimer_EnableTriggerMode          0u
#define InactivityTimer_InterruptOnCaptureCount    0u
#define InactivityTimer_RunModeUsed                0u
#define InactivityTimer_ControlRegRemoved          0u

#if defined(InactivityTimer_TimerUDB_sCTRLReg_SyncCtl_ctrlreg__CONTROL_REG)
    #define InactivityTimer_UDB_CONTROL_REG_REMOVED            (0u)
#elif  (InactivityTimer_UsingFixedFunction)
    #define InactivityTimer_UDB_CONTROL_REG_REMOVED            (0u)
#else 
    #define InactivityTimer_UDB_CONTROL_REG_REMOVED            (1u)
#endif /* End InactivityTimer_TimerUDB_sCTRLReg_SyncCtl_ctrlreg__CONTROL_REG */


/***************************************
*       Type defines
***************************************/


/**************************************************************************
 * Sleep Wakeup Backup structure for Timer Component
 *************************************************************************/
typedef struct
{
    uint8 TimerEnableState;
    #if(!InactivityTimer_UsingFixedFunction)

        uint16 TimerUdb;
        uint8 InterruptMaskValue;
        #if (InactivityTimer_UsingHWCaptureCounter)
            uint8 TimerCaptureCounter;
        #endif /* variable declarations for backing up non retention registers in CY_UDB_V1 */

        #if (!InactivityTimer_UDB_CONTROL_REG_REMOVED)
            uint8 TimerControlRegister;
        #endif /* variable declaration for backing up enable state of the Timer */
    #endif /* define backup variables only for UDB implementation. Fixed function registers are all retention */

}InactivityTimer_backupStruct;


/***************************************
*       Function Prototypes
***************************************/

void    InactivityTimer_Start(void) ;
void    InactivityTimer_Stop(void) ;

void    InactivityTimer_SetInterruptMode(uint8 interruptMode) ;
uint8   InactivityTimer_ReadStatusRegister(void) ;
/* Deprecated function. Do not use this in future. Retained for backward compatibility */
#define InactivityTimer_GetInterruptSource() InactivityTimer_ReadStatusRegister()

#if(!InactivityTimer_UDB_CONTROL_REG_REMOVED)
    uint8   InactivityTimer_ReadControlRegister(void) ;
    void    InactivityTimer_WriteControlRegister(uint8 control) ;
#endif /* (!InactivityTimer_UDB_CONTROL_REG_REMOVED) */

uint16  InactivityTimer_ReadPeriod(void) ;
void    InactivityTimer_WritePeriod(uint16 period) ;
uint16  InactivityTimer_ReadCounter(void) ;
void    InactivityTimer_WriteCounter(uint16 counter) ;
uint16  InactivityTimer_ReadCapture(void) ;
void    InactivityTimer_SoftwareCapture(void) ;

#if(!InactivityTimer_UsingFixedFunction) /* UDB Prototypes */
    #if (InactivityTimer_SoftwareCaptureMode)
        void    InactivityTimer_SetCaptureMode(uint8 captureMode) ;
    #endif /* (!InactivityTimer_UsingFixedFunction) */

    #if (InactivityTimer_SoftwareTriggerMode)
        void    InactivityTimer_SetTriggerMode(uint8 triggerMode) ;
    #endif /* (InactivityTimer_SoftwareTriggerMode) */

    #if (InactivityTimer_EnableTriggerMode)
        void    InactivityTimer_EnableTrigger(void) ;
        void    InactivityTimer_DisableTrigger(void) ;
    #endif /* (InactivityTimer_EnableTriggerMode) */


    #if(InactivityTimer_InterruptOnCaptureCount)
        void    InactivityTimer_SetInterruptCount(uint8 interruptCount) ;
    #endif /* (InactivityTimer_InterruptOnCaptureCount) */

    #if (InactivityTimer_UsingHWCaptureCounter)
        void    InactivityTimer_SetCaptureCount(uint8 captureCount) ;
        uint8   InactivityTimer_ReadCaptureCount(void) ;
    #endif /* (InactivityTimer_UsingHWCaptureCounter) */

    void InactivityTimer_ClearFIFO(void) ;
#endif /* UDB Prototypes */

/* Sleep Retention APIs */
void InactivityTimer_Init(void)          ;
void InactivityTimer_Enable(void)        ;
void InactivityTimer_SaveConfig(void)    ;
void InactivityTimer_RestoreConfig(void) ;
void InactivityTimer_Sleep(void)         ;
void InactivityTimer_Wakeup(void)        ;


/***************************************
*   Enumerated Types and Parameters
***************************************/

/* Enumerated Type B_Timer__CaptureModes, Used in Capture Mode */
#define InactivityTimer__B_TIMER__CM_NONE 0
#define InactivityTimer__B_TIMER__CM_RISINGEDGE 1
#define InactivityTimer__B_TIMER__CM_FALLINGEDGE 2
#define InactivityTimer__B_TIMER__CM_EITHEREDGE 3
#define InactivityTimer__B_TIMER__CM_SOFTWARE 4



/* Enumerated Type B_Timer__TriggerModes, Used in Trigger Mode */
#define InactivityTimer__B_TIMER__TM_NONE 0x00u
#define InactivityTimer__B_TIMER__TM_RISINGEDGE 0x04u
#define InactivityTimer__B_TIMER__TM_FALLINGEDGE 0x08u
#define InactivityTimer__B_TIMER__TM_EITHEREDGE 0x0Cu
#define InactivityTimer__B_TIMER__TM_SOFTWARE 0x10u


/***************************************
*    Initialial Parameter Constants
***************************************/

#define InactivityTimer_INIT_PERIOD             999u
#define InactivityTimer_INIT_CAPTURE_MODE       ((uint8)((uint8)0u << InactivityTimer_CTRL_CAP_MODE_SHIFT))
#define InactivityTimer_INIT_TRIGGER_MODE       ((uint8)((uint8)0u << InactivityTimer_CTRL_TRIG_MODE_SHIFT))
#if (InactivityTimer_UsingFixedFunction)
    #define InactivityTimer_INIT_INTERRUPT_MODE (((uint8)((uint8)1u << InactivityTimer_STATUS_TC_INT_MASK_SHIFT)) | \
                                                  ((uint8)((uint8)0 << InactivityTimer_STATUS_CAPTURE_INT_MASK_SHIFT)))
#else
    #define InactivityTimer_INIT_INTERRUPT_MODE (((uint8)((uint8)1u << InactivityTimer_STATUS_TC_INT_MASK_SHIFT)) | \
                                                 ((uint8)((uint8)0 << InactivityTimer_STATUS_CAPTURE_INT_MASK_SHIFT)) | \
                                                 ((uint8)((uint8)0 << InactivityTimer_STATUS_FIFOFULL_INT_MASK_SHIFT)))
#endif /* (InactivityTimer_UsingFixedFunction) */
#define InactivityTimer_INIT_CAPTURE_COUNT      (2u)
#define InactivityTimer_INIT_INT_CAPTURE_COUNT  ((uint8)((uint8)(1u - 1u) << InactivityTimer_CTRL_INTCNT_SHIFT))


/***************************************
*           Registers
***************************************/

#if (InactivityTimer_UsingFixedFunction) /* Implementation Specific Registers and Register Constants */


    /***************************************
    *    Fixed Function Registers
    ***************************************/

    #define InactivityTimer_STATUS         (*(reg8 *) InactivityTimer_TimerHW__SR0 )
    /* In Fixed Function Block Status and Mask are the same register */
    #define InactivityTimer_STATUS_MASK    (*(reg8 *) InactivityTimer_TimerHW__SR0 )
    #define InactivityTimer_CONTROL        (*(reg8 *) InactivityTimer_TimerHW__CFG0)
    #define InactivityTimer_CONTROL2       (*(reg8 *) InactivityTimer_TimerHW__CFG1)
    #define InactivityTimer_CONTROL2_PTR   ( (reg8 *) InactivityTimer_TimerHW__CFG1)
    #define InactivityTimer_RT1            (*(reg8 *) InactivityTimer_TimerHW__RT1)
    #define InactivityTimer_RT1_PTR        ( (reg8 *) InactivityTimer_TimerHW__RT1)

    #if (CY_PSOC3 || CY_PSOC5LP)
        #define InactivityTimer_CONTROL3       (*(reg8 *) InactivityTimer_TimerHW__CFG2)
        #define InactivityTimer_CONTROL3_PTR   ( (reg8 *) InactivityTimer_TimerHW__CFG2)
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */
    #define InactivityTimer_GLOBAL_ENABLE  (*(reg8 *) InactivityTimer_TimerHW__PM_ACT_CFG)
    #define InactivityTimer_GLOBAL_STBY_ENABLE  (*(reg8 *) InactivityTimer_TimerHW__PM_STBY_CFG)

    #define InactivityTimer_CAPTURE_LSB         (* (reg16 *) InactivityTimer_TimerHW__CAP0 )
    #define InactivityTimer_CAPTURE_LSB_PTR       ((reg16 *) InactivityTimer_TimerHW__CAP0 )
    #define InactivityTimer_PERIOD_LSB          (* (reg16 *) InactivityTimer_TimerHW__PER0 )
    #define InactivityTimer_PERIOD_LSB_PTR        ((reg16 *) InactivityTimer_TimerHW__PER0 )
    #define InactivityTimer_COUNTER_LSB         (* (reg16 *) InactivityTimer_TimerHW__CNT_CMP0 )
    #define InactivityTimer_COUNTER_LSB_PTR       ((reg16 *) InactivityTimer_TimerHW__CNT_CMP0 )


    /***************************************
    *    Register Constants
    ***************************************/

    /* Fixed Function Block Chosen */
    #define InactivityTimer_BLOCK_EN_MASK                     InactivityTimer_TimerHW__PM_ACT_MSK
    #define InactivityTimer_BLOCK_STBY_EN_MASK                InactivityTimer_TimerHW__PM_STBY_MSK

    /* Control Register Bit Locations */
    /* Interrupt Count - Not valid for Fixed Function Block */
    #define InactivityTimer_CTRL_INTCNT_SHIFT                  0x00u
    /* Trigger Polarity - Not valid for Fixed Function Block */
    #define InactivityTimer_CTRL_TRIG_MODE_SHIFT               0x00u
    /* Trigger Enable - Not valid for Fixed Function Block */
    #define InactivityTimer_CTRL_TRIG_EN_SHIFT                 0x00u
    /* Capture Polarity - Not valid for Fixed Function Block */
    #define InactivityTimer_CTRL_CAP_MODE_SHIFT                0x00u
    /* Timer Enable - As defined in Register Map, part of TMRX_CFG0 register */
    #define InactivityTimer_CTRL_ENABLE_SHIFT                  0x00u

    /* Control Register Bit Masks */
    #define InactivityTimer_CTRL_ENABLE                        ((uint8)((uint8)0x01u << InactivityTimer_CTRL_ENABLE_SHIFT))

    /* Control2 Register Bit Masks */
    /* As defined in Register Map, Part of the TMRX_CFG1 register */
    #define InactivityTimer_CTRL2_IRQ_SEL_SHIFT                 0x00u
    #define InactivityTimer_CTRL2_IRQ_SEL                      ((uint8)((uint8)0x01u << InactivityTimer_CTRL2_IRQ_SEL_SHIFT))

    #if (CY_PSOC5A)
        /* Use CFG1 Mode bits to set run mode */
        /* As defined by Verilog Implementation */
        #define InactivityTimer_CTRL_MODE_SHIFT                 0x01u
        #define InactivityTimer_CTRL_MODE_MASK                 ((uint8)((uint8)0x07u << InactivityTimer_CTRL_MODE_SHIFT))
    #endif /* (CY_PSOC5A) */
    #if (CY_PSOC3 || CY_PSOC5LP)
        /* Control3 Register Bit Locations */
        #define InactivityTimer_CTRL_RCOD_SHIFT        0x02u
        #define InactivityTimer_CTRL_ENBL_SHIFT        0x00u
        #define InactivityTimer_CTRL_MODE_SHIFT        0x00u

        /* Control3 Register Bit Masks */
        #define InactivityTimer_CTRL_RCOD_MASK  ((uint8)((uint8)0x03u << InactivityTimer_CTRL_RCOD_SHIFT)) /* ROD and COD bit masks */
        #define InactivityTimer_CTRL_ENBL_MASK  ((uint8)((uint8)0x80u << InactivityTimer_CTRL_ENBL_SHIFT)) /* HW_EN bit mask */
        #define InactivityTimer_CTRL_MODE_MASK  ((uint8)((uint8)0x03u << InactivityTimer_CTRL_MODE_SHIFT)) /* Run mode bit mask */

        #define InactivityTimer_CTRL_RCOD       ((uint8)((uint8)0x03u << InactivityTimer_CTRL_RCOD_SHIFT))
        #define InactivityTimer_CTRL_ENBL       ((uint8)((uint8)0x80u << InactivityTimer_CTRL_ENBL_SHIFT))
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */

    /*RT1 Synch Constants: Applicable for PSoC3 and PSoC5LP */
    #define InactivityTimer_RT1_SHIFT                       0x04u
    /* Sync TC and CMP bit masks */
    #define InactivityTimer_RT1_MASK                        ((uint8)((uint8)0x03u << InactivityTimer_RT1_SHIFT))
    #define InactivityTimer_SYNC                            ((uint8)((uint8)0x03u << InactivityTimer_RT1_SHIFT))
    #define InactivityTimer_SYNCDSI_SHIFT                   0x00u
    /* Sync all DSI inputs with Mask  */
    #define InactivityTimer_SYNCDSI_MASK                    ((uint8)((uint8)0x0Fu << InactivityTimer_SYNCDSI_SHIFT))
    /* Sync all DSI inputs */
    #define InactivityTimer_SYNCDSI_EN                      ((uint8)((uint8)0x0Fu << InactivityTimer_SYNCDSI_SHIFT))

    #define InactivityTimer_CTRL_MODE_PULSEWIDTH            ((uint8)((uint8)0x01u << InactivityTimer_CTRL_MODE_SHIFT))
    #define InactivityTimer_CTRL_MODE_PERIOD                ((uint8)((uint8)0x02u << InactivityTimer_CTRL_MODE_SHIFT))
    #define InactivityTimer_CTRL_MODE_CONTINUOUS            ((uint8)((uint8)0x00u << InactivityTimer_CTRL_MODE_SHIFT))

    /* Status Register Bit Locations */
    /* As defined in Register Map, part of TMRX_SR0 register */
    #define InactivityTimer_STATUS_TC_SHIFT                 0x07u
    /* As defined in Register Map, part of TMRX_SR0 register, Shared with Compare Status */
    #define InactivityTimer_STATUS_CAPTURE_SHIFT            0x06u
    /* As defined in Register Map, part of TMRX_SR0 register */
    #define InactivityTimer_STATUS_TC_INT_MASK_SHIFT        (InactivityTimer_STATUS_TC_SHIFT - 0x04u)
    /* As defined in Register Map, part of TMRX_SR0 register, Shared with Compare Status */
    #define InactivityTimer_STATUS_CAPTURE_INT_MASK_SHIFT   (InactivityTimer_STATUS_CAPTURE_SHIFT - 0x04u)

    /* Status Register Bit Masks */
    #define InactivityTimer_STATUS_TC                       ((uint8)((uint8)0x01u << InactivityTimer_STATUS_TC_SHIFT))
    #define InactivityTimer_STATUS_CAPTURE                  ((uint8)((uint8)0x01u << InactivityTimer_STATUS_CAPTURE_SHIFT))
    /* Interrupt Enable Bit-Mask for interrupt on TC */
    #define InactivityTimer_STATUS_TC_INT_MASK              ((uint8)((uint8)0x01u << InactivityTimer_STATUS_TC_INT_MASK_SHIFT))
    /* Interrupt Enable Bit-Mask for interrupt on Capture */
    #define InactivityTimer_STATUS_CAPTURE_INT_MASK         ((uint8)((uint8)0x01u << InactivityTimer_STATUS_CAPTURE_INT_MASK_SHIFT))

#else   /* UDB Registers and Register Constants */


    /***************************************
    *           UDB Registers
    ***************************************/

    #define InactivityTimer_STATUS              (* (reg8 *) InactivityTimer_TimerUDB_rstSts_stsreg__STATUS_REG )
    #define InactivityTimer_STATUS_MASK         (* (reg8 *) InactivityTimer_TimerUDB_rstSts_stsreg__MASK_REG)
    #define InactivityTimer_STATUS_AUX_CTRL     (* (reg8 *) InactivityTimer_TimerUDB_rstSts_stsreg__STATUS_AUX_CTL_REG)
    #define InactivityTimer_CONTROL             (* (reg8 *) InactivityTimer_TimerUDB_sCTRLReg_SyncCtl_ctrlreg__CONTROL_REG )
    
    #if(InactivityTimer_Resolution <= 8u) /* 8-bit Timer */
        #define InactivityTimer_CAPTURE_LSB         (* (reg8 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__F0_REG )
        #define InactivityTimer_CAPTURE_LSB_PTR       ((reg8 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__F0_REG )
        #define InactivityTimer_PERIOD_LSB          (* (reg8 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__D0_REG )
        #define InactivityTimer_PERIOD_LSB_PTR        ((reg8 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__D0_REG )
        #define InactivityTimer_COUNTER_LSB         (* (reg8 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__A0_REG )
        #define InactivityTimer_COUNTER_LSB_PTR       ((reg8 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__A0_REG )
    #elif(InactivityTimer_Resolution <= 16u) /* 8-bit Timer */
        #if(CY_PSOC3) /* 8-bit addres space */
            #define InactivityTimer_CAPTURE_LSB         (* (reg16 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__F0_REG )
            #define InactivityTimer_CAPTURE_LSB_PTR       ((reg16 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__F0_REG )
            #define InactivityTimer_PERIOD_LSB          (* (reg16 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__D0_REG )
            #define InactivityTimer_PERIOD_LSB_PTR        ((reg16 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__D0_REG )
            #define InactivityTimer_COUNTER_LSB         (* (reg16 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__A0_REG )
            #define InactivityTimer_COUNTER_LSB_PTR       ((reg16 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__A0_REG )
        #else /* 16-bit address space */
            #define InactivityTimer_CAPTURE_LSB         (* (reg16 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__16BIT_F0_REG )
            #define InactivityTimer_CAPTURE_LSB_PTR       ((reg16 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__16BIT_F0_REG )
            #define InactivityTimer_PERIOD_LSB          (* (reg16 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__16BIT_D0_REG )
            #define InactivityTimer_PERIOD_LSB_PTR        ((reg16 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__16BIT_D0_REG )
            #define InactivityTimer_COUNTER_LSB         (* (reg16 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__16BIT_A0_REG )
            #define InactivityTimer_COUNTER_LSB_PTR       ((reg16 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__16BIT_A0_REG )
        #endif /* CY_PSOC3 */
    #elif(InactivityTimer_Resolution <= 24u)/* 24-bit Timer */
        #define InactivityTimer_CAPTURE_LSB         (* (reg32 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__F0_REG )
        #define InactivityTimer_CAPTURE_LSB_PTR       ((reg32 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__F0_REG )
        #define InactivityTimer_PERIOD_LSB          (* (reg32 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__D0_REG )
        #define InactivityTimer_PERIOD_LSB_PTR        ((reg32 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__D0_REG )
        #define InactivityTimer_COUNTER_LSB         (* (reg32 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__A0_REG )
        #define InactivityTimer_COUNTER_LSB_PTR       ((reg32 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__A0_REG )
    #else /* 32-bit Timer */
        #if(CY_PSOC3 || CY_PSOC5) /* 8-bit address space */
            #define InactivityTimer_CAPTURE_LSB         (* (reg32 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__F0_REG )
            #define InactivityTimer_CAPTURE_LSB_PTR       ((reg32 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__F0_REG )
            #define InactivityTimer_PERIOD_LSB          (* (reg32 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__D0_REG )
            #define InactivityTimer_PERIOD_LSB_PTR        ((reg32 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__D0_REG )
            #define InactivityTimer_COUNTER_LSB         (* (reg32 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__A0_REG )
            #define InactivityTimer_COUNTER_LSB_PTR       ((reg32 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__A0_REG )
        #else /* 32-bit address space */
            #define InactivityTimer_CAPTURE_LSB         (* (reg32 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__32BIT_F0_REG )
            #define InactivityTimer_CAPTURE_LSB_PTR       ((reg32 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__32BIT_F0_REG )
            #define InactivityTimer_PERIOD_LSB          (* (reg32 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__32BIT_D0_REG )
            #define InactivityTimer_PERIOD_LSB_PTR        ((reg32 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__32BIT_D0_REG )
            #define InactivityTimer_COUNTER_LSB         (* (reg32 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__32BIT_A0_REG )
            #define InactivityTimer_COUNTER_LSB_PTR       ((reg32 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__32BIT_A0_REG )
        #endif /* CY_PSOC3 || CY_PSOC5 */ 
    #endif

    #define InactivityTimer_COUNTER_LSB_PTR_8BIT       ((reg8 *) InactivityTimer_TimerUDB_sT16_timerdp_u0__A0_REG )
    
    #if (InactivityTimer_UsingHWCaptureCounter)
        #define InactivityTimer_CAP_COUNT              (*(reg8 *) InactivityTimer_TimerUDB_sCapCount_counter__PERIOD_REG )
        #define InactivityTimer_CAP_COUNT_PTR          ( (reg8 *) InactivityTimer_TimerUDB_sCapCount_counter__PERIOD_REG )
        #define InactivityTimer_CAPTURE_COUNT_CTRL     (*(reg8 *) InactivityTimer_TimerUDB_sCapCount_counter__CONTROL_AUX_CTL_REG )
        #define InactivityTimer_CAPTURE_COUNT_CTRL_PTR ( (reg8 *) InactivityTimer_TimerUDB_sCapCount_counter__CONTROL_AUX_CTL_REG )
    #endif /* (InactivityTimer_UsingHWCaptureCounter) */


    /***************************************
    *       Register Constants
    ***************************************/

    /* Control Register Bit Locations */
    #define InactivityTimer_CTRL_INTCNT_SHIFT              0x00u       /* As defined by Verilog Implementation */
    #define InactivityTimer_CTRL_TRIG_MODE_SHIFT           0x02u       /* As defined by Verilog Implementation */
    #define InactivityTimer_CTRL_TRIG_EN_SHIFT             0x04u       /* As defined by Verilog Implementation */
    #define InactivityTimer_CTRL_CAP_MODE_SHIFT            0x05u       /* As defined by Verilog Implementation */
    #define InactivityTimer_CTRL_ENABLE_SHIFT              0x07u       /* As defined by Verilog Implementation */

    /* Control Register Bit Masks */
    #define InactivityTimer_CTRL_INTCNT_MASK               ((uint8)((uint8)0x03u << InactivityTimer_CTRL_INTCNT_SHIFT))
    #define InactivityTimer_CTRL_TRIG_MODE_MASK            ((uint8)((uint8)0x03u << InactivityTimer_CTRL_TRIG_MODE_SHIFT))
    #define InactivityTimer_CTRL_TRIG_EN                   ((uint8)((uint8)0x01u << InactivityTimer_CTRL_TRIG_EN_SHIFT))
    #define InactivityTimer_CTRL_CAP_MODE_MASK             ((uint8)((uint8)0x03u << InactivityTimer_CTRL_CAP_MODE_SHIFT))
    #define InactivityTimer_CTRL_ENABLE                    ((uint8)((uint8)0x01u << InactivityTimer_CTRL_ENABLE_SHIFT))

    /* Bit Counter (7-bit) Control Register Bit Definitions */
    /* As defined by the Register map for the AUX Control Register */
    #define InactivityTimer_CNTR_ENABLE                    0x20u

    /* Status Register Bit Locations */
    #define InactivityTimer_STATUS_TC_SHIFT                0x00u  /* As defined by Verilog Implementation */
    #define InactivityTimer_STATUS_CAPTURE_SHIFT           0x01u  /* As defined by Verilog Implementation */
    #define InactivityTimer_STATUS_TC_INT_MASK_SHIFT       InactivityTimer_STATUS_TC_SHIFT
    #define InactivityTimer_STATUS_CAPTURE_INT_MASK_SHIFT  InactivityTimer_STATUS_CAPTURE_SHIFT
    #define InactivityTimer_STATUS_FIFOFULL_SHIFT          0x02u  /* As defined by Verilog Implementation */
    #define InactivityTimer_STATUS_FIFONEMP_SHIFT          0x03u  /* As defined by Verilog Implementation */
    #define InactivityTimer_STATUS_FIFOFULL_INT_MASK_SHIFT InactivityTimer_STATUS_FIFOFULL_SHIFT

    /* Status Register Bit Masks */
    /* Sticky TC Event Bit-Mask */
    #define InactivityTimer_STATUS_TC                      ((uint8)((uint8)0x01u << InactivityTimer_STATUS_TC_SHIFT))
    /* Sticky Capture Event Bit-Mask */
    #define InactivityTimer_STATUS_CAPTURE                 ((uint8)((uint8)0x01u << InactivityTimer_STATUS_CAPTURE_SHIFT))
    /* Interrupt Enable Bit-Mask */
    #define InactivityTimer_STATUS_TC_INT_MASK             ((uint8)((uint8)0x01u << InactivityTimer_STATUS_TC_SHIFT))
    /* Interrupt Enable Bit-Mask */
    #define InactivityTimer_STATUS_CAPTURE_INT_MASK        ((uint8)((uint8)0x01u << InactivityTimer_STATUS_CAPTURE_SHIFT))
    /* NOT-Sticky FIFO Full Bit-Mask */
    #define InactivityTimer_STATUS_FIFOFULL                ((uint8)((uint8)0x01u << InactivityTimer_STATUS_FIFOFULL_SHIFT))
    /* NOT-Sticky FIFO Not Empty Bit-Mask */
    #define InactivityTimer_STATUS_FIFONEMP                ((uint8)((uint8)0x01u << InactivityTimer_STATUS_FIFONEMP_SHIFT))
    /* Interrupt Enable Bit-Mask */
    #define InactivityTimer_STATUS_FIFOFULL_INT_MASK       ((uint8)((uint8)0x01u << InactivityTimer_STATUS_FIFOFULL_SHIFT))

    #define InactivityTimer_STATUS_ACTL_INT_EN             0x10u   /* As defined for the ACTL Register */

    /* Datapath Auxillary Control Register definitions */
    #define InactivityTimer_AUX_CTRL_FIFO0_CLR             0x01u   /* As defined by Register map */
    #define InactivityTimer_AUX_CTRL_FIFO1_CLR             0x02u   /* As defined by Register map */
    #define InactivityTimer_AUX_CTRL_FIFO0_LVL             0x04u   /* As defined by Register map */
    #define InactivityTimer_AUX_CTRL_FIFO1_LVL             0x08u   /* As defined by Register map */
    #define InactivityTimer_STATUS_ACTL_INT_EN_MASK        0x10u   /* As defined for the ACTL Register */

#endif /* Implementation Specific Registers and Register Constants */

#endif  /* CY_Timer_v2_30_InactivityTimer_H */


/* [] END OF FILE */
