/*******************************************************************************
* File Name: PWMTEST.c
* Version 3.30
*
* Description:
*  The PWM User Module consist of an 8 or 16-bit counter with two 8 or 16-bit
*  comparitors. Each instance of this user module is capable of generating
*  two PWM outputs with the same period. The pulse width is selectable between
*  1 and 255/65535. The period is selectable between 2 and 255/65536 clocks.
*  The compare value output may be configured to be active when the present
*  counter is less than or less than/equal to the compare value.
*  A terminal count output is also provided. It generates a pulse one clock
*  width wide when the counter is equal to zero.
*
* Note:
*
*******************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#include "PWMTEST.h"

/* Error message for removed <resource> through optimization */
#ifdef PWMTEST_PWMUDB_genblk1_ctrlreg__REMOVED
    #error PWM_v3_30 detected with a constant 0 for the enable or \
         constant 1 for reset. This will prevent the component from operating.
#endif /* PWMTEST_PWMUDB_genblk1_ctrlreg__REMOVED */

uint8 PWMTEST_initVar = 0u;


/*******************************************************************************
* Function Name: PWMTEST_Start
********************************************************************************
*
* Summary:
*  The start function initializes the pwm with the default values, the
*  enables the counter to begin counting.  It does not enable interrupts,
*  the EnableInt command should be called if interrupt generation is required.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  PWMTEST_initVar: Is modified when this function is called for the
*   first time. Is used to ensure that initialization happens only once.
*
*******************************************************************************/
void PWMTEST_Start(void) 
{
    /* If not Initialized then initialize all required hardware and software */
    if(PWMTEST_initVar == 0u)
    {
        PWMTEST_Init();
        PWMTEST_initVar = 1u;
    }
    PWMTEST_Enable();

}


/*******************************************************************************
* Function Name: PWMTEST_Init
********************************************************************************
*
* Summary:
*  Initialize component's parameters to the parameters set by user in the
*  customizer of the component placed onto schematic. Usually called in
*  PWMTEST_Start().
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void PWMTEST_Init(void) 
{
    #if (PWMTEST_UsingFixedFunction || PWMTEST_UseControl)
        uint8 ctrl;
    #endif /* (PWMTEST_UsingFixedFunction || PWMTEST_UseControl) */

    #if(!PWMTEST_UsingFixedFunction)
        #if(PWMTEST_UseStatus)
            /* Interrupt State Backup for Critical Region*/
            uint8 PWMTEST_interruptState;
        #endif /* (PWMTEST_UseStatus) */
    #endif /* (!PWMTEST_UsingFixedFunction) */

    #if (PWMTEST_UsingFixedFunction)
        /* You are allowed to write the compare value (FF only) */
        PWMTEST_CONTROL |= PWMTEST_CFG0_MODE;
        #if (PWMTEST_DeadBand2_4)
            PWMTEST_CONTROL |= PWMTEST_CFG0_DB;
        #endif /* (PWMTEST_DeadBand2_4) */

        ctrl = PWMTEST_CONTROL3 & ((uint8 )(~PWMTEST_CTRL_CMPMODE1_MASK));
        PWMTEST_CONTROL3 = ctrl | PWMTEST_DEFAULT_COMPARE1_MODE;

         /* Clear and Set SYNCTC and SYNCCMP bits of RT1 register */
        PWMTEST_RT1 &= ((uint8)(~PWMTEST_RT1_MASK));
        PWMTEST_RT1 |= PWMTEST_SYNC;

        /*Enable DSI Sync all all inputs of the PWM*/
        PWMTEST_RT1 &= ((uint8)(~PWMTEST_SYNCDSI_MASK));
        PWMTEST_RT1 |= PWMTEST_SYNCDSI_EN;

    #elif (PWMTEST_UseControl)
        /* Set the default compare mode defined in the parameter */
        ctrl = PWMTEST_CONTROL & ((uint8)(~PWMTEST_CTRL_CMPMODE2_MASK)) &
                ((uint8)(~PWMTEST_CTRL_CMPMODE1_MASK));
        PWMTEST_CONTROL = ctrl | PWMTEST_DEFAULT_COMPARE2_MODE |
                                   PWMTEST_DEFAULT_COMPARE1_MODE;
    #endif /* (PWMTEST_UsingFixedFunction) */

    #if (!PWMTEST_UsingFixedFunction)
        #if (PWMTEST_Resolution == 8)
            /* Set FIFO 0 to 1 byte register for period*/
            PWMTEST_AUX_CONTROLDP0 |= (PWMTEST_AUX_CTRL_FIFO0_CLR);
        #else /* (PWMTEST_Resolution == 16)*/
            /* Set FIFO 0 to 1 byte register for period */
            PWMTEST_AUX_CONTROLDP0 |= (PWMTEST_AUX_CTRL_FIFO0_CLR);
            PWMTEST_AUX_CONTROLDP1 |= (PWMTEST_AUX_CTRL_FIFO0_CLR);
        #endif /* (PWMTEST_Resolution == 8) */

        PWMTEST_WriteCounter(PWMTEST_INIT_PERIOD_VALUE);
    #endif /* (!PWMTEST_UsingFixedFunction) */

    PWMTEST_WritePeriod(PWMTEST_INIT_PERIOD_VALUE);

        #if (PWMTEST_UseOneCompareMode)
            PWMTEST_WriteCompare(PWMTEST_INIT_COMPARE_VALUE1);
        #else
            PWMTEST_WriteCompare1(PWMTEST_INIT_COMPARE_VALUE1);
            PWMTEST_WriteCompare2(PWMTEST_INIT_COMPARE_VALUE2);
        #endif /* (PWMTEST_UseOneCompareMode) */

        #if (PWMTEST_KillModeMinTime)
            PWMTEST_WriteKillTime(PWMTEST_MinimumKillTime);
        #endif /* (PWMTEST_KillModeMinTime) */

        #if (PWMTEST_DeadBandUsed)
            PWMTEST_WriteDeadTime(PWMTEST_INIT_DEAD_TIME);
        #endif /* (PWMTEST_DeadBandUsed) */

    #if (PWMTEST_UseStatus || PWMTEST_UsingFixedFunction)
        PWMTEST_SetInterruptMode(PWMTEST_INIT_INTERRUPTS_MODE);
    #endif /* (PWMTEST_UseStatus || PWMTEST_UsingFixedFunction) */

    #if (PWMTEST_UsingFixedFunction)
        /* Globally Enable the Fixed Function Block chosen */
        PWMTEST_GLOBAL_ENABLE |= PWMTEST_BLOCK_EN_MASK;
        /* Set the Interrupt source to come from the status register */
        PWMTEST_CONTROL2 |= PWMTEST_CTRL2_IRQ_SEL;
    #else
        #if(PWMTEST_UseStatus)

            /* CyEnterCriticalRegion and CyExitCriticalRegion are used to mark following region critical*/
            /* Enter Critical Region*/
            PWMTEST_interruptState = CyEnterCriticalSection();
            /* Use the interrupt output of the status register for IRQ output */
            PWMTEST_STATUS_AUX_CTRL |= PWMTEST_STATUS_ACTL_INT_EN_MASK;

             /* Exit Critical Region*/
            CyExitCriticalSection(PWMTEST_interruptState);

            /* Clear the FIFO to enable the PWMTEST_STATUS_FIFOFULL
                   bit to be set on FIFO full. */
            PWMTEST_ClearFIFO();
        #endif /* (PWMTEST_UseStatus) */
    #endif /* (PWMTEST_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: PWMTEST_Enable
********************************************************************************
*
* Summary:
*  Enables the PWM block operation
*
* Parameters:
*  None
*
* Return:
*  None
*
* Side Effects:
*  This works only if software enable mode is chosen
*
*******************************************************************************/
void PWMTEST_Enable(void) 
{
    /* Globally Enable the Fixed Function Block chosen */
    #if (PWMTEST_UsingFixedFunction)
        PWMTEST_GLOBAL_ENABLE |= PWMTEST_BLOCK_EN_MASK;
        PWMTEST_GLOBAL_STBY_ENABLE |= PWMTEST_BLOCK_STBY_EN_MASK;
    #endif /* (PWMTEST_UsingFixedFunction) */

    /* Enable the PWM from the control register  */
    #if (PWMTEST_UseControl || PWMTEST_UsingFixedFunction)
        PWMTEST_CONTROL |= PWMTEST_CTRL_ENABLE;
    #endif /* (PWMTEST_UseControl || PWMTEST_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: PWMTEST_Stop
********************************************************************************
*
* Summary:
*  The stop function halts the PWM, but does not change any modes or disable
*  interrupts.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Side Effects:
*  If the Enable mode is set to Hardware only then this function
*  has no effect on the operation of the PWM
*
*******************************************************************************/
void PWMTEST_Stop(void) 
{
    #if (PWMTEST_UseControl || PWMTEST_UsingFixedFunction)
        PWMTEST_CONTROL &= ((uint8)(~PWMTEST_CTRL_ENABLE));
    #endif /* (PWMTEST_UseControl || PWMTEST_UsingFixedFunction) */

    /* Globally disable the Fixed Function Block chosen */
    #if (PWMTEST_UsingFixedFunction)
        PWMTEST_GLOBAL_ENABLE &= ((uint8)(~PWMTEST_BLOCK_EN_MASK));
        PWMTEST_GLOBAL_STBY_ENABLE &= ((uint8)(~PWMTEST_BLOCK_STBY_EN_MASK));
    #endif /* (PWMTEST_UsingFixedFunction) */
}

#if (PWMTEST_UseOneCompareMode)
    #if (PWMTEST_CompareMode1SW)


        /*******************************************************************************
        * Function Name: PWMTEST_SetCompareMode
        ********************************************************************************
        *
        * Summary:
        *  This function writes the Compare Mode for the pwm output when in Dither mode,
        *  Center Align Mode or One Output Mode.
        *
        * Parameters:
        *  comparemode:  The new compare mode for the PWM output. Use the compare types
        *                defined in the H file as input arguments.
        *
        * Return:
        *  None
        *
        *******************************************************************************/
        void PWMTEST_SetCompareMode(uint8 comparemode) 
        {
            #if(PWMTEST_UsingFixedFunction)

                #if(0 != PWMTEST_CTRL_CMPMODE1_SHIFT)
                    uint8 comparemodemasked = ((uint8)((uint8)comparemode << PWMTEST_CTRL_CMPMODE1_SHIFT));
                #else
                    uint8 comparemodemasked = comparemode;
                #endif /* (0 != PWMTEST_CTRL_CMPMODE1_SHIFT) */

                PWMTEST_CONTROL3 &= ((uint8)(~PWMTEST_CTRL_CMPMODE1_MASK)); /*Clear Existing Data */
                PWMTEST_CONTROL3 |= comparemodemasked;

            #elif (PWMTEST_UseControl)

                #if(0 != PWMTEST_CTRL_CMPMODE1_SHIFT)
                    uint8 comparemode1masked = ((uint8)((uint8)comparemode << PWMTEST_CTRL_CMPMODE1_SHIFT)) &
                                                PWMTEST_CTRL_CMPMODE1_MASK;
                #else
                    uint8 comparemode1masked = comparemode & PWMTEST_CTRL_CMPMODE1_MASK;
                #endif /* (0 != PWMTEST_CTRL_CMPMODE1_SHIFT) */

                #if(0 != PWMTEST_CTRL_CMPMODE2_SHIFT)
                    uint8 comparemode2masked = ((uint8)((uint8)comparemode << PWMTEST_CTRL_CMPMODE2_SHIFT)) &
                                               PWMTEST_CTRL_CMPMODE2_MASK;
                #else
                    uint8 comparemode2masked = comparemode & PWMTEST_CTRL_CMPMODE2_MASK;
                #endif /* (0 != PWMTEST_CTRL_CMPMODE2_SHIFT) */

                /*Clear existing mode */
                PWMTEST_CONTROL &= ((uint8)(~(PWMTEST_CTRL_CMPMODE1_MASK |
                                            PWMTEST_CTRL_CMPMODE2_MASK)));
                PWMTEST_CONTROL |= (comparemode1masked | comparemode2masked);

            #else
                uint8 temp = comparemode;
            #endif /* (PWMTEST_UsingFixedFunction) */
        }
    #endif /* PWMTEST_CompareMode1SW */

#else /* UseOneCompareMode */

    #if (PWMTEST_CompareMode1SW)


        /*******************************************************************************
        * Function Name: PWMTEST_SetCompareMode1
        ********************************************************************************
        *
        * Summary:
        *  This function writes the Compare Mode for the pwm or pwm1 output
        *
        * Parameters:
        *  comparemode:  The new compare mode for the PWM output. Use the compare types
        *                defined in the H file as input arguments.
        *
        * Return:
        *  None
        *
        *******************************************************************************/
        void PWMTEST_SetCompareMode1(uint8 comparemode) 
        {
            #if(0 != PWMTEST_CTRL_CMPMODE1_SHIFT)
                uint8 comparemodemasked = ((uint8)((uint8)comparemode << PWMTEST_CTRL_CMPMODE1_SHIFT)) &
                                           PWMTEST_CTRL_CMPMODE1_MASK;
            #else
                uint8 comparemodemasked = comparemode & PWMTEST_CTRL_CMPMODE1_MASK;
            #endif /* (0 != PWMTEST_CTRL_CMPMODE1_SHIFT) */

            #if (PWMTEST_UseControl)
                PWMTEST_CONTROL &= ((uint8)(~PWMTEST_CTRL_CMPMODE1_MASK)); /*Clear existing mode */
                PWMTEST_CONTROL |= comparemodemasked;
            #endif /* (PWMTEST_UseControl) */
        }
    #endif /* PWMTEST_CompareMode1SW */

#if (PWMTEST_CompareMode2SW)


    /*******************************************************************************
    * Function Name: PWMTEST_SetCompareMode2
    ********************************************************************************
    *
    * Summary:
    *  This function writes the Compare Mode for the pwm or pwm2 output
    *
    * Parameters:
    *  comparemode:  The new compare mode for the PWM output. Use the compare types
    *                defined in the H file as input arguments.
    *
    * Return:
    *  None
    *
    *******************************************************************************/
    void PWMTEST_SetCompareMode2(uint8 comparemode) 
    {

        #if(0 != PWMTEST_CTRL_CMPMODE2_SHIFT)
            uint8 comparemodemasked = ((uint8)((uint8)comparemode << PWMTEST_CTRL_CMPMODE2_SHIFT)) &
                                                 PWMTEST_CTRL_CMPMODE2_MASK;
        #else
            uint8 comparemodemasked = comparemode & PWMTEST_CTRL_CMPMODE2_MASK;
        #endif /* (0 != PWMTEST_CTRL_CMPMODE2_SHIFT) */

        #if (PWMTEST_UseControl)
            PWMTEST_CONTROL &= ((uint8)(~PWMTEST_CTRL_CMPMODE2_MASK)); /*Clear existing mode */
            PWMTEST_CONTROL |= comparemodemasked;
        #endif /* (PWMTEST_UseControl) */
    }
    #endif /*PWMTEST_CompareMode2SW */

#endif /* UseOneCompareMode */


#if (!PWMTEST_UsingFixedFunction)


    /*******************************************************************************
    * Function Name: PWMTEST_WriteCounter
    ********************************************************************************
    *
    * Summary:
    *  Writes a new counter value directly to the counter register. This will be
    *  implemented for that currently running period and only that period. This API
    *  is valid only for UDB implementation and not available for fixed function
    *  PWM implementation.
    *
    * Parameters:
    *  counter:  The period new period counter value.
    *
    * Return:
    *  None
    *
    * Side Effects:
    *  The PWM Period will be reloaded when a counter value will be a zero
    *
    *******************************************************************************/
    void PWMTEST_WriteCounter(uint8 counter) \
                                       
    {
        CY_SET_REG8(PWMTEST_COUNTER_LSB_PTR, counter);
    }


    /*******************************************************************************
    * Function Name: PWMTEST_ReadCounter
    ********************************************************************************
    *
    * Summary:
    *  This function returns the current value of the counter.  It doesn't matter
    *  if the counter is enabled or running.
    *
    * Parameters:
    *  None
    *
    * Return:
    *  The current value of the counter.
    *
    *******************************************************************************/
    uint8 PWMTEST_ReadCounter(void) 
    {
        /* Force capture by reading Accumulator */
        /* Must first do a software capture to be able to read the counter */
        /* It is up to the user code to make sure there isn't already captured data in the FIFO */
          (void)CY_GET_REG8(PWMTEST_COUNTERCAP_LSB_PTR_8BIT);

        /* Read the data from the FIFO */
        return (CY_GET_REG8(PWMTEST_CAPTURE_LSB_PTR));
    }

    #if (PWMTEST_UseStatus)


        /*******************************************************************************
        * Function Name: PWMTEST_ClearFIFO
        ********************************************************************************
        *
        * Summary:
        *  This function clears all capture data from the capture FIFO
        *
        * Parameters:
        *  None
        *
        * Return:
        *  None
        *
        *******************************************************************************/
        void PWMTEST_ClearFIFO(void) 
        {
            while(0u != (PWMTEST_ReadStatusRegister() & PWMTEST_STATUS_FIFONEMPTY))
            {
                (void)PWMTEST_ReadCapture();
            }
        }

    #endif /* PWMTEST_UseStatus */

#endif /* !PWMTEST_UsingFixedFunction */


/*******************************************************************************
* Function Name: PWMTEST_WritePeriod
********************************************************************************
*
* Summary:
*  This function is used to change the period of the counter.  The new period
*  will be loaded the next time terminal count is detected.
*
* Parameters:
*  period:  Period value. May be between 1 and (2^Resolution)-1.  A value of 0
*           will result in the counter remaining at zero.
*
* Return:
*  None
*
*******************************************************************************/
void PWMTEST_WritePeriod(uint8 period) 
{
    #if(PWMTEST_UsingFixedFunction)
        CY_SET_REG16(PWMTEST_PERIOD_LSB_PTR, (uint16)period);
    #else
        CY_SET_REG8(PWMTEST_PERIOD_LSB_PTR, period);
    #endif /* (PWMTEST_UsingFixedFunction) */
}

#if (PWMTEST_UseOneCompareMode)


    /*******************************************************************************
    * Function Name: PWMTEST_WriteCompare
    ********************************************************************************
    *
    * Summary:
    *  This funtion is used to change the compare1 value when the PWM is in Dither
    *  mode. The compare output will reflect the new value on the next UDB clock.
    *  The compare output will be driven high when the present counter value is
    *  compared to the compare value based on the compare mode defined in
    *  Dither Mode.
    *
    * Parameters:
    *  compare:  New compare value.
    *
    * Return:
    *  None
    *
    * Side Effects:
    *  This function is only available if the PWM mode parameter is set to
    *  Dither Mode, Center Aligned Mode or One Output Mode
    *
    *******************************************************************************/
    void PWMTEST_WriteCompare(uint8 compare) \
                                       
    {
        #if(PWMTEST_UsingFixedFunction)
            CY_SET_REG16(PWMTEST_COMPARE1_LSB_PTR, (uint16)compare);
        #else
            CY_SET_REG8(PWMTEST_COMPARE1_LSB_PTR, compare);
        #endif /* (PWMTEST_UsingFixedFunction) */

        #if (PWMTEST_PWMMode == PWMTEST__B_PWM__DITHER)
            #if(PWMTEST_UsingFixedFunction)
                CY_SET_REG16(PWMTEST_COMPARE2_LSB_PTR, (uint16)(compare + 1u));
            #else
                CY_SET_REG8(PWMTEST_COMPARE2_LSB_PTR, (compare + 1u));
            #endif /* (PWMTEST_UsingFixedFunction) */
        #endif /* (PWMTEST_PWMMode == PWMTEST__B_PWM__DITHER) */
    }


#else


    /*******************************************************************************
    * Function Name: PWMTEST_WriteCompare1
    ********************************************************************************
    *
    * Summary:
    *  This funtion is used to change the compare1 value.  The compare output will
    *  reflect the new value on the next UDB clock.  The compare output will be
    *  driven high when the present counter value is less than or less than or
    *  equal to the compare register, depending on the mode.
    *
    * Parameters:
    *  compare:  New compare value.
    *
    * Return:
    *  None
    *
    *******************************************************************************/
    void PWMTEST_WriteCompare1(uint8 compare) \
                                        
    {
        #if(PWMTEST_UsingFixedFunction)
            CY_SET_REG16(PWMTEST_COMPARE1_LSB_PTR, (uint16)compare);
        #else
            CY_SET_REG8(PWMTEST_COMPARE1_LSB_PTR, compare);
        #endif /* (PWMTEST_UsingFixedFunction) */
    }


    /*******************************************************************************
    * Function Name: PWMTEST_WriteCompare2
    ********************************************************************************
    *
    * Summary:
    *  This funtion is used to change the compare value, for compare1 output.
    *  The compare output will reflect the new value on the next UDB clock.
    *  The compare output will be driven high when the present counter value is
    *  less than or less than or equal to the compare register, depending on the
    *  mode.
    *
    * Parameters:
    *  compare:  New compare value.
    *
    * Return:
    *  None
    *
    *******************************************************************************/
    void PWMTEST_WriteCompare2(uint8 compare) \
                                        
    {
        #if(PWMTEST_UsingFixedFunction)
            CY_SET_REG16(PWMTEST_COMPARE2_LSB_PTR, compare);
        #else
            CY_SET_REG8(PWMTEST_COMPARE2_LSB_PTR, compare);
        #endif /* (PWMTEST_UsingFixedFunction) */
    }
#endif /* UseOneCompareMode */

#if (PWMTEST_DeadBandUsed)


    /*******************************************************************************
    * Function Name: PWMTEST_WriteDeadTime
    ********************************************************************************
    *
    * Summary:
    *  This function writes the dead-band counts to the corresponding register
    *
    * Parameters:
    *  deadtime:  Number of counts for dead time
    *
    * Return:
    *  None
    *
    *******************************************************************************/
    void PWMTEST_WriteDeadTime(uint8 deadtime) 
    {
        /* If using the Dead Band 1-255 mode then just write the register */
        #if(!PWMTEST_DeadBand2_4)
            CY_SET_REG8(PWMTEST_DEADBAND_COUNT_PTR, deadtime);
        #else
            /* Otherwise the data has to be masked and offset */
            /* Clear existing data */
            PWMTEST_DEADBAND_COUNT &= ((uint8)(~PWMTEST_DEADBAND_COUNT_MASK));

            /* Set new dead time */
            #if(PWMTEST_DEADBAND_COUNT_SHIFT)
                PWMTEST_DEADBAND_COUNT |= ((uint8)((uint8)deadtime << PWMTEST_DEADBAND_COUNT_SHIFT)) &
                                                    PWMTEST_DEADBAND_COUNT_MASK;
            #else
                PWMTEST_DEADBAND_COUNT |= deadtime & PWMTEST_DEADBAND_COUNT_MASK;
            #endif /* (PWMTEST_DEADBAND_COUNT_SHIFT) */

        #endif /* (!PWMTEST_DeadBand2_4) */
    }


    /*******************************************************************************
    * Function Name: PWMTEST_ReadDeadTime
    ********************************************************************************
    *
    * Summary:
    *  This function reads the dead-band counts from the corresponding register
    *
    * Parameters:
    *  None
    *
    * Return:
    *  Dead Band Counts
    *
    *******************************************************************************/
    uint8 PWMTEST_ReadDeadTime(void) 
    {
        /* If using the Dead Band 1-255 mode then just read the register */
        #if(!PWMTEST_DeadBand2_4)
            return (CY_GET_REG8(PWMTEST_DEADBAND_COUNT_PTR));
        #else

            /* Otherwise the data has to be masked and offset */
            #if(PWMTEST_DEADBAND_COUNT_SHIFT)
                return ((uint8)(((uint8)(PWMTEST_DEADBAND_COUNT & PWMTEST_DEADBAND_COUNT_MASK)) >>
                                                                           PWMTEST_DEADBAND_COUNT_SHIFT));
            #else
                return (PWMTEST_DEADBAND_COUNT & PWMTEST_DEADBAND_COUNT_MASK);
            #endif /* (PWMTEST_DEADBAND_COUNT_SHIFT) */
        #endif /* (!PWMTEST_DeadBand2_4) */
    }
#endif /* DeadBandUsed */

#if (PWMTEST_UseStatus || PWMTEST_UsingFixedFunction)


    /*******************************************************************************
    * Function Name: PWMTEST_SetInterruptMode
    ********************************************************************************
    *
    * Summary:
    *  This function configures the interrupts mask control of theinterrupt
    *  source status register.
    *
    * Parameters:
    *  uint8 interruptMode: Bit field containing the interrupt sources enabled
    *
    * Return:
    *  None
    *
    *******************************************************************************/
    void PWMTEST_SetInterruptMode(uint8 interruptMode) 
    {
        CY_SET_REG8(PWMTEST_STATUS_MASK_PTR, interruptMode);
    }


    /*******************************************************************************
    * Function Name: PWMTEST_ReadStatusRegister
    ********************************************************************************
    *
    * Summary:
    *  This function returns the current state of the status register.
    *
    * Parameters:
    *  None
    *
    * Return:
    *  uint8 : Current status register value. The status register bits are:
    *  [7:6] : Unused(0)
    *  [5]   : Kill event output
    *  [4]   : FIFO not empty
    *  [3]   : FIFO full
    *  [2]   : Terminal count
    *  [1]   : Compare output 2
    *  [0]   : Compare output 1
    *
    *******************************************************************************/
    uint8 PWMTEST_ReadStatusRegister(void) 
    {
        return (CY_GET_REG8(PWMTEST_STATUS_PTR));
    }

#endif /* (PWMTEST_UseStatus || PWMTEST_UsingFixedFunction) */


#if (PWMTEST_UseControl)


    /*******************************************************************************
    * Function Name: PWMTEST_ReadControlRegister
    ********************************************************************************
    *
    * Summary:
    *  Returns the current state of the control register. This API is available
    *  only if the control register is not removed.
    *
    * Parameters:
    *  None
    *
    * Return:
    *  uint8 : Current control register value
    *
    *******************************************************************************/
    uint8 PWMTEST_ReadControlRegister(void) 
    {
        uint8 result;

        result = CY_GET_REG8(PWMTEST_CONTROL_PTR);
        return (result);
    }


    /*******************************************************************************
    * Function Name: PWMTEST_WriteControlRegister
    ********************************************************************************
    *
    * Summary:
    *  Sets the bit field of the control register. This API is available only if
    *  the control register is not removed.
    *
    * Parameters:
    *  uint8 control: Control register bit field, The status register bits are:
    *  [7]   : PWM Enable
    *  [6]   : Reset
    *  [5:3] : Compare Mode2
    *  [2:0] : Compare Mode2
    *
    * Return:
    *  None
    *
    *******************************************************************************/
    void PWMTEST_WriteControlRegister(uint8 control) 
    {
        CY_SET_REG8(PWMTEST_CONTROL_PTR, control);
    }

#endif /* (PWMTEST_UseControl) */


#if (!PWMTEST_UsingFixedFunction)


    /*******************************************************************************
    * Function Name: PWMTEST_ReadCapture
    ********************************************************************************
    *
    * Summary:
    *  Reads the capture value from the capture FIFO.
    *
    * Parameters:
    *  None
    *
    * Return:
    *  uint8/uint16: The current capture value
    *
    *******************************************************************************/
    uint8 PWMTEST_ReadCapture(void) 
    {
        return (CY_GET_REG8(PWMTEST_CAPTURE_LSB_PTR));
    }

#endif /* (!PWMTEST_UsingFixedFunction) */


#if (PWMTEST_UseOneCompareMode)


    /*******************************************************************************
    * Function Name: PWMTEST_ReadCompare
    ********************************************************************************
    *
    * Summary:
    *  Reads the compare value for the compare output when the PWM Mode parameter is
    *  set to Dither mode, Center Aligned mode, or One Output mode.
    *
    * Parameters:
    *  None
    *
    * Return:
    *  uint8/uint16: Current compare value
    *
    *******************************************************************************/
    uint8 PWMTEST_ReadCompare(void) 
    {
        #if(PWMTEST_UsingFixedFunction)
            return ((uint8)CY_GET_REG16(PWMTEST_COMPARE1_LSB_PTR));
        #else
            return (CY_GET_REG8(PWMTEST_COMPARE1_LSB_PTR));
        #endif /* (PWMTEST_UsingFixedFunction) */
    }

#else


    /*******************************************************************************
    * Function Name: PWMTEST_ReadCompare1
    ********************************************************************************
    *
    * Summary:
    *  Reads the compare value for the compare1 output.
    *
    * Parameters:
    *  None
    *
    * Return:
    *  uint8/uint16: Current compare value.
    *
    *******************************************************************************/
    uint8 PWMTEST_ReadCompare1(void) 
    {
        return (CY_GET_REG8(PWMTEST_COMPARE1_LSB_PTR));
    }


    /*******************************************************************************
    * Function Name: PWMTEST_ReadCompare2
    ********************************************************************************
    *
    * Summary:
    *  Reads the compare value for the compare2 output.
    *
    * Parameters:
    *  None
    *
    * Return:
    *  uint8/uint16: Current compare value.
    *
    *******************************************************************************/
    uint8 PWMTEST_ReadCompare2(void) 
    {
        return (CY_GET_REG8(PWMTEST_COMPARE2_LSB_PTR));
    }

#endif /* (PWMTEST_UseOneCompareMode) */


/*******************************************************************************
* Function Name: PWMTEST_ReadPeriod
********************************************************************************
*
* Summary:
*  Reads the period value used by the PWM hardware.
*
* Parameters:
*  None
*
* Return:
*  uint8/16: Period value
*
*******************************************************************************/
uint8 PWMTEST_ReadPeriod(void) 
{
    #if(PWMTEST_UsingFixedFunction)
        return ((uint8)CY_GET_REG16(PWMTEST_PERIOD_LSB_PTR));
    #else
        return (CY_GET_REG8(PWMTEST_PERIOD_LSB_PTR));
    #endif /* (PWMTEST_UsingFixedFunction) */
}

#if ( PWMTEST_KillModeMinTime)


    /*******************************************************************************
    * Function Name: PWMTEST_WriteKillTime
    ********************************************************************************
    *
    * Summary:
    *  Writes the kill time value used by the hardware when the Kill Mode
    *  is set to Minimum Time.
    *
    * Parameters:
    *  uint8: Minimum Time kill counts
    *
    * Return:
    *  None
    *
    *******************************************************************************/
    void PWMTEST_WriteKillTime(uint8 killtime) 
    {
        CY_SET_REG8(PWMTEST_KILLMODEMINTIME_PTR, killtime);
    }


    /*******************************************************************************
    * Function Name: PWMTEST_ReadKillTime
    ********************************************************************************
    *
    * Summary:
    *  Reads the kill time value used by the hardware when the Kill Mode is set
    *  to Minimum Time.
    *
    * Parameters:
    *  None
    *
    * Return:
    *  uint8: The current Minimum Time kill counts
    *
    *******************************************************************************/
    uint8 PWMTEST_ReadKillTime(void) 
    {
        return (CY_GET_REG8(PWMTEST_KILLMODEMINTIME_PTR));
    }

#endif /* ( PWMTEST_KillModeMinTime) */

/* [] END OF FILE */
