/*******************************************************************************
* File Name: PWMTEST.h
* Version 3.30
*
* Description:
*  Contains the prototypes and constants for the functions available to the
*  PWM user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_PWM_PWMTEST_H)
#define CY_PWM_PWMTEST_H

#include "cyfitter.h"
#include "cytypes.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

extern uint8 PWMTEST_initVar;


/***************************************
* Conditional Compilation Parameters
***************************************/
#define PWMTEST_Resolution                     (8u)
#define PWMTEST_UsingFixedFunction             (0u)
#define PWMTEST_DeadBandMode                   (0u)
#define PWMTEST_KillModeMinTime                (0u)
#define PWMTEST_KillMode                       (0u)
#define PWMTEST_PWMMode                        (0u)
#define PWMTEST_PWMModeIsCenterAligned         (0u)
#define PWMTEST_DeadBandUsed                   (0u)
#define PWMTEST_DeadBand2_4                    (0u)

#if !defined(PWMTEST_PWMUDB_genblk8_stsreg__REMOVED)
    #define PWMTEST_UseStatus                  (1u)
#else
    #define PWMTEST_UseStatus                  (0u)
#endif /* !defined(PWMTEST_PWMUDB_genblk8_stsreg__REMOVED) */

#if !defined(PWMTEST_PWMUDB_genblk1_ctrlreg__REMOVED)
    #define PWMTEST_UseControl                 (1u)
#else
    #define PWMTEST_UseControl                 (0u)
#endif /* !defined(PWMTEST_PWMUDB_genblk1_ctrlreg__REMOVED) */

#define PWMTEST_UseOneCompareMode              (1u)
#define PWMTEST_MinimumKillTime                (1u)
#define PWMTEST_EnableMode                     (0u)

#define PWMTEST_CompareMode1SW                 (0u)
#define PWMTEST_CompareMode2SW                 (0u)

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component PWM_v3_30 requires cy_boot v3.0 or later
#endif /* (CY_ PSOC5LP) */

/* Use Kill Mode Enumerated Types */
#define PWMTEST__B_PWM__DISABLED 0
#define PWMTEST__B_PWM__ASYNCHRONOUS 1
#define PWMTEST__B_PWM__SINGLECYCLE 2
#define PWMTEST__B_PWM__LATCHED 3
#define PWMTEST__B_PWM__MINTIME 4


/* Use Dead Band Mode Enumerated Types */
#define PWMTEST__B_PWM__DBMDISABLED 0
#define PWMTEST__B_PWM__DBM_2_4_CLOCKS 1
#define PWMTEST__B_PWM__DBM_256_CLOCKS 2


/* Used PWM Mode Enumerated Types */
#define PWMTEST__B_PWM__ONE_OUTPUT 0
#define PWMTEST__B_PWM__TWO_OUTPUTS 1
#define PWMTEST__B_PWM__DUAL_EDGE 2
#define PWMTEST__B_PWM__CENTER_ALIGN 3
#define PWMTEST__B_PWM__DITHER 5
#define PWMTEST__B_PWM__HARDWARESELECT 4


/* Used PWM Compare Mode Enumerated Types */
#define PWMTEST__B_PWM__LESS_THAN 1
#define PWMTEST__B_PWM__LESS_THAN_OR_EQUAL 2
#define PWMTEST__B_PWM__GREATER_THAN 3
#define PWMTEST__B_PWM__GREATER_THAN_OR_EQUAL_TO 4
#define PWMTEST__B_PWM__EQUAL 0
#define PWMTEST__B_PWM__FIRMWARE 5



/***************************************
* Data Struct Definition
***************************************/


/**************************************************************************
 * Sleep Wakeup Backup structure for PWM Component
 *************************************************************************/
typedef struct
{

    uint8 PWMEnableState;

    #if(!PWMTEST_UsingFixedFunction)
        uint8 PWMUdb;               /* PWM Current Counter value  */
        #if(!PWMTEST_PWMModeIsCenterAligned)
            uint8 PWMPeriod;
        #endif /* (!PWMTEST_PWMModeIsCenterAligned) */
        #if (PWMTEST_UseStatus)
            uint8 InterruptMaskValue;   /* PWM Current Interrupt Mask */
        #endif /* (PWMTEST_UseStatus) */

        /* Backup for Deadband parameters */
        #if(PWMTEST_DeadBandMode == PWMTEST__B_PWM__DBM_256_CLOCKS || \
            PWMTEST_DeadBandMode == PWMTEST__B_PWM__DBM_2_4_CLOCKS)
            uint8 PWMdeadBandValue; /* Dead Band Counter Current Value */
        #endif /* deadband count is either 2-4 clocks or 256 clocks */

        /* Backup Kill Mode Counter*/
        #if(PWMTEST_KillModeMinTime)
            uint8 PWMKillCounterPeriod; /* Kill Mode period value */
        #endif /* (PWMTEST_KillModeMinTime) */

        /* Backup control register */
        #if(PWMTEST_UseControl)
            uint8 PWMControlRegister; /* PWM Control Register value */
        #endif /* (PWMTEST_UseControl) */

    #endif /* (!PWMTEST_UsingFixedFunction) */

}PWMTEST_backupStruct;


/***************************************
*        Function Prototypes
 **************************************/

void    PWMTEST_Start(void) ;
void    PWMTEST_Stop(void) ;

#if (PWMTEST_UseStatus || PWMTEST_UsingFixedFunction)
    void  PWMTEST_SetInterruptMode(uint8 interruptMode) ;
    uint8 PWMTEST_ReadStatusRegister(void) ;
#endif /* (PWMTEST_UseStatus || PWMTEST_UsingFixedFunction) */

#define PWMTEST_GetInterruptSource() PWMTEST_ReadStatusRegister()

#if (PWMTEST_UseControl)
    uint8 PWMTEST_ReadControlRegister(void) ;
    void  PWMTEST_WriteControlRegister(uint8 control)
          ;
#endif /* (PWMTEST_UseControl) */

#if (PWMTEST_UseOneCompareMode)
   #if (PWMTEST_CompareMode1SW)
       void    PWMTEST_SetCompareMode(uint8 comparemode)
               ;
   #endif /* (PWMTEST_CompareMode1SW) */
#else
    #if (PWMTEST_CompareMode1SW)
        void    PWMTEST_SetCompareMode1(uint8 comparemode)
                ;
    #endif /* (PWMTEST_CompareMode1SW) */
    #if (PWMTEST_CompareMode2SW)
        void    PWMTEST_SetCompareMode2(uint8 comparemode)
                ;
    #endif /* (PWMTEST_CompareMode2SW) */
#endif /* (PWMTEST_UseOneCompareMode) */

#if (!PWMTEST_UsingFixedFunction)
    uint8   PWMTEST_ReadCounter(void) ;
    uint8 PWMTEST_ReadCapture(void) ;

    #if (PWMTEST_UseStatus)
            void PWMTEST_ClearFIFO(void) ;
    #endif /* (PWMTEST_UseStatus) */

    void    PWMTEST_WriteCounter(uint8 counter)
            ;
#endif /* (!PWMTEST_UsingFixedFunction) */

void    PWMTEST_WritePeriod(uint8 period)
        ;
uint8 PWMTEST_ReadPeriod(void) ;

#if (PWMTEST_UseOneCompareMode)
    void    PWMTEST_WriteCompare(uint8 compare)
            ;
    uint8 PWMTEST_ReadCompare(void) ;
#else
    void    PWMTEST_WriteCompare1(uint8 compare)
            ;
    uint8 PWMTEST_ReadCompare1(void) ;
    void    PWMTEST_WriteCompare2(uint8 compare)
            ;
    uint8 PWMTEST_ReadCompare2(void) ;
#endif /* (PWMTEST_UseOneCompareMode) */


#if (PWMTEST_DeadBandUsed)
    void    PWMTEST_WriteDeadTime(uint8 deadtime) ;
    uint8   PWMTEST_ReadDeadTime(void) ;
#endif /* (PWMTEST_DeadBandUsed) */

#if ( PWMTEST_KillModeMinTime)
    void PWMTEST_WriteKillTime(uint8 killtime) ;
    uint8 PWMTEST_ReadKillTime(void) ;
#endif /* ( PWMTEST_KillModeMinTime) */

void PWMTEST_Init(void) ;
void PWMTEST_Enable(void) ;
void PWMTEST_Sleep(void) ;
void PWMTEST_Wakeup(void) ;
void PWMTEST_SaveConfig(void) ;
void PWMTEST_RestoreConfig(void) ;


/***************************************
*         Initialization Values
**************************************/
#define PWMTEST_INIT_PERIOD_VALUE          (11u)
#define PWMTEST_INIT_COMPARE_VALUE1        (2u)
#define PWMTEST_INIT_COMPARE_VALUE2        (63u)
#define PWMTEST_INIT_INTERRUPTS_MODE       (uint8)(((uint8)(0u <<   \
                                                    PWMTEST_STATUS_TC_INT_EN_MASK_SHIFT)) | \
                                                    (uint8)((uint8)(0u <<  \
                                                    PWMTEST_STATUS_CMP2_INT_EN_MASK_SHIFT)) | \
                                                    (uint8)((uint8)(0u <<  \
                                                    PWMTEST_STATUS_CMP1_INT_EN_MASK_SHIFT )) | \
                                                    (uint8)((uint8)(0u <<  \
                                                    PWMTEST_STATUS_KILL_INT_EN_MASK_SHIFT )))
#define PWMTEST_DEFAULT_COMPARE2_MODE      (uint8)((uint8)1u <<  PWMTEST_CTRL_CMPMODE2_SHIFT)
#define PWMTEST_DEFAULT_COMPARE1_MODE      (uint8)((uint8)1u <<  PWMTEST_CTRL_CMPMODE1_SHIFT)
#define PWMTEST_INIT_DEAD_TIME             (1u)


/********************************
*         Registers
******************************** */

#if (PWMTEST_UsingFixedFunction)
   #define PWMTEST_PERIOD_LSB              (*(reg16 *) PWMTEST_PWMHW__PER0)
   #define PWMTEST_PERIOD_LSB_PTR          ( (reg16 *) PWMTEST_PWMHW__PER0)
   #define PWMTEST_COMPARE1_LSB            (*(reg16 *) PWMTEST_PWMHW__CNT_CMP0)
   #define PWMTEST_COMPARE1_LSB_PTR        ( (reg16 *) PWMTEST_PWMHW__CNT_CMP0)
   #define PWMTEST_COMPARE2_LSB            (0x00u)
   #define PWMTEST_COMPARE2_LSB_PTR        (0x00u)
   #define PWMTEST_COUNTER_LSB             (*(reg16 *) PWMTEST_PWMHW__CNT_CMP0)
   #define PWMTEST_COUNTER_LSB_PTR         ( (reg16 *) PWMTEST_PWMHW__CNT_CMP0)
   #define PWMTEST_CAPTURE_LSB             (*(reg16 *) PWMTEST_PWMHW__CAP0)
   #define PWMTEST_CAPTURE_LSB_PTR         ( (reg16 *) PWMTEST_PWMHW__CAP0)
   #define PWMTEST_RT1                     (*(reg8 *)  PWMTEST_PWMHW__RT1)
   #define PWMTEST_RT1_PTR                 ( (reg8 *)  PWMTEST_PWMHW__RT1)

#else
   #if (PWMTEST_Resolution == 8u) /* 8bit - PWM */

       #if(PWMTEST_PWMModeIsCenterAligned)
           #define PWMTEST_PERIOD_LSB      (*(reg8 *)  PWMTEST_PWMUDB_sP8_pwmdp_u0__D1_REG)
           #define PWMTEST_PERIOD_LSB_PTR  ((reg8 *)   PWMTEST_PWMUDB_sP8_pwmdp_u0__D1_REG)
       #else
           #define PWMTEST_PERIOD_LSB      (*(reg8 *)  PWMTEST_PWMUDB_sP8_pwmdp_u0__F0_REG)
           #define PWMTEST_PERIOD_LSB_PTR  ((reg8 *)   PWMTEST_PWMUDB_sP8_pwmdp_u0__F0_REG)
       #endif /* (PWMTEST_PWMModeIsCenterAligned) */

       #define PWMTEST_COMPARE1_LSB        (*(reg8 *)  PWMTEST_PWMUDB_sP8_pwmdp_u0__D0_REG)
       #define PWMTEST_COMPARE1_LSB_PTR    ((reg8 *)   PWMTEST_PWMUDB_sP8_pwmdp_u0__D0_REG)
       #define PWMTEST_COMPARE2_LSB        (*(reg8 *)  PWMTEST_PWMUDB_sP8_pwmdp_u0__D1_REG)
       #define PWMTEST_COMPARE2_LSB_PTR    ((reg8 *)   PWMTEST_PWMUDB_sP8_pwmdp_u0__D1_REG)
       #define PWMTEST_COUNTERCAP_LSB      (*(reg8 *)  PWMTEST_PWMUDB_sP8_pwmdp_u0__A1_REG)
       #define PWMTEST_COUNTERCAP_LSB_PTR  ((reg8 *)   PWMTEST_PWMUDB_sP8_pwmdp_u0__A1_REG)
       #define PWMTEST_COUNTER_LSB         (*(reg8 *)  PWMTEST_PWMUDB_sP8_pwmdp_u0__A0_REG)
       #define PWMTEST_COUNTER_LSB_PTR     ((reg8 *)   PWMTEST_PWMUDB_sP8_pwmdp_u0__A0_REG)
       #define PWMTEST_CAPTURE_LSB         (*(reg8 *)  PWMTEST_PWMUDB_sP8_pwmdp_u0__F1_REG)
       #define PWMTEST_CAPTURE_LSB_PTR     ((reg8 *)   PWMTEST_PWMUDB_sP8_pwmdp_u0__F1_REG)

   #else
        #if(CY_PSOC3) /* 8-bit address space */
            #if(PWMTEST_PWMModeIsCenterAligned)
               #define PWMTEST_PERIOD_LSB      (*(reg16 *) PWMTEST_PWMUDB_sP8_pwmdp_u0__D1_REG)
               #define PWMTEST_PERIOD_LSB_PTR  ((reg16 *)  PWMTEST_PWMUDB_sP8_pwmdp_u0__D1_REG)
            #else
               #define PWMTEST_PERIOD_LSB      (*(reg16 *) PWMTEST_PWMUDB_sP8_pwmdp_u0__F0_REG)
               #define PWMTEST_PERIOD_LSB_PTR  ((reg16 *)  PWMTEST_PWMUDB_sP8_pwmdp_u0__F0_REG)
            #endif /* (PWMTEST_PWMModeIsCenterAligned) */

            #define PWMTEST_COMPARE1_LSB       (*(reg16 *) PWMTEST_PWMUDB_sP8_pwmdp_u0__D0_REG)
            #define PWMTEST_COMPARE1_LSB_PTR   ((reg16 *)  PWMTEST_PWMUDB_sP8_pwmdp_u0__D0_REG)
            #define PWMTEST_COMPARE2_LSB       (*(reg16 *) PWMTEST_PWMUDB_sP8_pwmdp_u0__D1_REG)
            #define PWMTEST_COMPARE2_LSB_PTR   ((reg16 *)  PWMTEST_PWMUDB_sP8_pwmdp_u0__D1_REG)
            #define PWMTEST_COUNTERCAP_LSB     (*(reg16 *) PWMTEST_PWMUDB_sP8_pwmdp_u0__A1_REG)
            #define PWMTEST_COUNTERCAP_LSB_PTR ((reg16 *)  PWMTEST_PWMUDB_sP8_pwmdp_u0__A1_REG)
            #define PWMTEST_COUNTER_LSB        (*(reg16 *) PWMTEST_PWMUDB_sP8_pwmdp_u0__A0_REG)
            #define PWMTEST_COUNTER_LSB_PTR    ((reg16 *)  PWMTEST_PWMUDB_sP8_pwmdp_u0__A0_REG)
            #define PWMTEST_CAPTURE_LSB        (*(reg16 *) PWMTEST_PWMUDB_sP8_pwmdp_u0__F1_REG)
            #define PWMTEST_CAPTURE_LSB_PTR    ((reg16 *)  PWMTEST_PWMUDB_sP8_pwmdp_u0__F1_REG)
        #else
            #if(PWMTEST_PWMModeIsCenterAligned)
               #define PWMTEST_PERIOD_LSB      (*(reg16 *) PWMTEST_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
               #define PWMTEST_PERIOD_LSB_PTR  ((reg16 *)  PWMTEST_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
            #else
               #define PWMTEST_PERIOD_LSB      (*(reg16 *) PWMTEST_PWMUDB_sP8_pwmdp_u0__16BIT_F0_REG)
               #define PWMTEST_PERIOD_LSB_PTR  ((reg16 *)  PWMTEST_PWMUDB_sP8_pwmdp_u0__16BIT_F0_REG)
            #endif /* (PWMTEST_PWMModeIsCenterAligned) */

            #define PWMTEST_COMPARE1_LSB       (*(reg16 *) PWMTEST_PWMUDB_sP8_pwmdp_u0__16BIT_D0_REG)
            #define PWMTEST_COMPARE1_LSB_PTR   ((reg16 *)  PWMTEST_PWMUDB_sP8_pwmdp_u0__16BIT_D0_REG)
            #define PWMTEST_COMPARE2_LSB       (*(reg16 *) PWMTEST_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
            #define PWMTEST_COMPARE2_LSB_PTR   ((reg16 *)  PWMTEST_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
            #define PWMTEST_COUNTERCAP_LSB     (*(reg16 *) PWMTEST_PWMUDB_sP8_pwmdp_u0__16BIT_A1_REG)
            #define PWMTEST_COUNTERCAP_LSB_PTR ((reg16 *)  PWMTEST_PWMUDB_sP8_pwmdp_u0__16BIT_A1_REG)
            #define PWMTEST_COUNTER_LSB        (*(reg16 *) PWMTEST_PWMUDB_sP8_pwmdp_u0__16BIT_A0_REG)
            #define PWMTEST_COUNTER_LSB_PTR    ((reg16 *)  PWMTEST_PWMUDB_sP8_pwmdp_u0__16BIT_A0_REG)
            #define PWMTEST_CAPTURE_LSB        (*(reg16 *) PWMTEST_PWMUDB_sP8_pwmdp_u0__16BIT_F1_REG)
            #define PWMTEST_CAPTURE_LSB_PTR    ((reg16 *)  PWMTEST_PWMUDB_sP8_pwmdp_u0__16BIT_F1_REG)
        #endif /* (CY_PSOC3) */

       #define PWMTEST_AUX_CONTROLDP1          (*(reg8 *)  PWMTEST_PWMUDB_sP8_pwmdp_u1__DP_AUX_CTL_REG)
       #define PWMTEST_AUX_CONTROLDP1_PTR      ((reg8 *)   PWMTEST_PWMUDB_sP8_pwmdp_u1__DP_AUX_CTL_REG)

   #endif /* (PWMTEST_Resolution == 8) */

   #define PWMTEST_COUNTERCAP_LSB_PTR_8BIT ( (reg8 *)  PWMTEST_PWMUDB_sP8_pwmdp_u0__A1_REG)
   #define PWMTEST_AUX_CONTROLDP0          (*(reg8 *)  PWMTEST_PWMUDB_sP8_pwmdp_u0__DP_AUX_CTL_REG)
   #define PWMTEST_AUX_CONTROLDP0_PTR      ((reg8 *)   PWMTEST_PWMUDB_sP8_pwmdp_u0__DP_AUX_CTL_REG)

#endif /* (PWMTEST_UsingFixedFunction) */

#if(PWMTEST_KillModeMinTime )
    #define PWMTEST_KILLMODEMINTIME        (*(reg8 *)  PWMTEST_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    #define PWMTEST_KILLMODEMINTIME_PTR    ((reg8 *)   PWMTEST_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    /* Fixed Function Block has no Kill Mode parameters because it is Asynchronous only */
#endif /* (PWMTEST_KillModeMinTime ) */

#if(PWMTEST_DeadBandMode == PWMTEST__B_PWM__DBM_256_CLOCKS)
    #define PWMTEST_DEADBAND_COUNT         (*(reg8 *)  PWMTEST_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define PWMTEST_DEADBAND_COUNT_PTR     ((reg8 *)   PWMTEST_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define PWMTEST_DEADBAND_LSB_PTR       ((reg8 *)   PWMTEST_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
    #define PWMTEST_DEADBAND_LSB           (*(reg8 *)  PWMTEST_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
#elif(PWMTEST_DeadBandMode == PWMTEST__B_PWM__DBM_2_4_CLOCKS)
    
    /* In Fixed Function Block these bits are in the control blocks control register */
    #if (PWMTEST_UsingFixedFunction)
        #define PWMTEST_DEADBAND_COUNT         (*(reg8 *)  PWMTEST_PWMHW__CFG0)
        #define PWMTEST_DEADBAND_COUNT_PTR     ((reg8 *)   PWMTEST_PWMHW__CFG0)
        #define PWMTEST_DEADBAND_COUNT_MASK    (uint8)((uint8)0x03u << PWMTEST_DEADBAND_COUNT_SHIFT)

        /* As defined by the Register Map as DEADBAND_PERIOD[1:0] in CFG0 */
        #define PWMTEST_DEADBAND_COUNT_SHIFT   (0x06u)
    #else
        /* Lower two bits of the added control register define the count 1-3 */
        #define PWMTEST_DEADBAND_COUNT         (*(reg8 *)  PWMTEST_PWMUDB_genblk7_dbctrlreg__CONTROL_REG)
        #define PWMTEST_DEADBAND_COUNT_PTR     ((reg8 *)   PWMTEST_PWMUDB_genblk7_dbctrlreg__CONTROL_REG)
        #define PWMTEST_DEADBAND_COUNT_MASK    (uint8)((uint8)0x03u << PWMTEST_DEADBAND_COUNT_SHIFT)

        /* As defined by the verilog implementation of the Control Register */
        #define PWMTEST_DEADBAND_COUNT_SHIFT   (0x00u)
    #endif /* (PWMTEST_UsingFixedFunction) */
#endif /* (PWMTEST_DeadBandMode == PWMTEST__B_PWM__DBM_256_CLOCKS) */



#if (PWMTEST_UsingFixedFunction)
    #define PWMTEST_STATUS                 (*(reg8 *) PWMTEST_PWMHW__SR0)
    #define PWMTEST_STATUS_PTR             ((reg8 *) PWMTEST_PWMHW__SR0)
    #define PWMTEST_STATUS_MASK            (*(reg8 *) PWMTEST_PWMHW__SR0)
    #define PWMTEST_STATUS_MASK_PTR        ((reg8 *) PWMTEST_PWMHW__SR0)
    #define PWMTEST_CONTROL                (*(reg8 *) PWMTEST_PWMHW__CFG0)
    #define PWMTEST_CONTROL_PTR            ((reg8 *) PWMTEST_PWMHW__CFG0)
    #define PWMTEST_CONTROL2               (*(reg8 *) PWMTEST_PWMHW__CFG1)
    #define PWMTEST_CONTROL3               (*(reg8 *) PWMTEST_PWMHW__CFG2)
    #define PWMTEST_GLOBAL_ENABLE          (*(reg8 *) PWMTEST_PWMHW__PM_ACT_CFG)
    #define PWMTEST_GLOBAL_ENABLE_PTR      ( (reg8 *) PWMTEST_PWMHW__PM_ACT_CFG)
    #define PWMTEST_GLOBAL_STBY_ENABLE     (*(reg8 *) PWMTEST_PWMHW__PM_STBY_CFG)
    #define PWMTEST_GLOBAL_STBY_ENABLE_PTR ( (reg8 *) PWMTEST_PWMHW__PM_STBY_CFG)


    /***********************************
    *          Constants
    ***********************************/

    /* Fixed Function Block Chosen */
    #define PWMTEST_BLOCK_EN_MASK          (PWMTEST_PWMHW__PM_ACT_MSK)
    #define PWMTEST_BLOCK_STBY_EN_MASK     (PWMTEST_PWMHW__PM_STBY_MSK)
    
    /* Control Register definitions */
    #define PWMTEST_CTRL_ENABLE_SHIFT      (0x00u)

    /* As defined by Register map as MODE_CFG bits in CFG2*/
    #define PWMTEST_CTRL_CMPMODE1_SHIFT    (0x04u)

    /* As defined by Register map */
    #define PWMTEST_CTRL_DEAD_TIME_SHIFT   (0x06u)  

    /* Fixed Function Block Only CFG register bit definitions */
    /*  Set to compare mode */
    #define PWMTEST_CFG0_MODE              (0x02u)   

    /* Enable the block to run */
    #define PWMTEST_CFG0_ENABLE            (0x01u)   
    
    /* As defined by Register map as DB bit in CFG0 */
    #define PWMTEST_CFG0_DB                (0x20u)   

    /* Control Register Bit Masks */
    #define PWMTEST_CTRL_ENABLE            (uint8)((uint8)0x01u << PWMTEST_CTRL_ENABLE_SHIFT)
    #define PWMTEST_CTRL_RESET             (uint8)((uint8)0x01u << PWMTEST_CTRL_RESET_SHIFT)
    #define PWMTEST_CTRL_CMPMODE2_MASK     (uint8)((uint8)0x07u << PWMTEST_CTRL_CMPMODE2_SHIFT)
    #define PWMTEST_CTRL_CMPMODE1_MASK     (uint8)((uint8)0x07u << PWMTEST_CTRL_CMPMODE1_SHIFT)

    /* Control2 Register Bit Masks */
    /* As defined in Register Map, Part of the TMRX_CFG1 register */
    #define PWMTEST_CTRL2_IRQ_SEL_SHIFT    (0x00u)
    #define PWMTEST_CTRL2_IRQ_SEL          (uint8)((uint8)0x01u << PWMTEST_CTRL2_IRQ_SEL_SHIFT)

    /* Status Register Bit Locations */
    /* As defined by Register map as TC in SR0 */
    #define PWMTEST_STATUS_TC_SHIFT        (0x07u)   
    
    /* As defined by the Register map as CAP_CMP in SR0 */
    #define PWMTEST_STATUS_CMP1_SHIFT      (0x06u)   

    /* Status Register Interrupt Enable Bit Locations */
    #define PWMTEST_STATUS_KILL_INT_EN_MASK_SHIFT          (0x00u)
    #define PWMTEST_STATUS_TC_INT_EN_MASK_SHIFT            (PWMTEST_STATUS_TC_SHIFT - 4u)
    #define PWMTEST_STATUS_CMP2_INT_EN_MASK_SHIFT          (0x00u)
    #define PWMTEST_STATUS_CMP1_INT_EN_MASK_SHIFT          (PWMTEST_STATUS_CMP1_SHIFT - 4u)

    /* Status Register Bit Masks */
    #define PWMTEST_STATUS_TC              (uint8)((uint8)0x01u << PWMTEST_STATUS_TC_SHIFT)
    #define PWMTEST_STATUS_CMP1            (uint8)((uint8)0x01u << PWMTEST_STATUS_CMP1_SHIFT)

    /* Status Register Interrupt Bit Masks */
    #define PWMTEST_STATUS_TC_INT_EN_MASK              (uint8)((uint8)PWMTEST_STATUS_TC >> 4u)
    #define PWMTEST_STATUS_CMP1_INT_EN_MASK            (uint8)((uint8)PWMTEST_STATUS_CMP1 >> 4u)

    /*RT1 Synch Constants */
    #define PWMTEST_RT1_SHIFT             (0x04u)

    /* Sync TC and CMP bit masks */
    #define PWMTEST_RT1_MASK              (uint8)((uint8)0x03u << PWMTEST_RT1_SHIFT)
    #define PWMTEST_SYNC                  (uint8)((uint8)0x03u << PWMTEST_RT1_SHIFT)
    #define PWMTEST_SYNCDSI_SHIFT         (0x00u)

    /* Sync all DSI inputs */
    #define PWMTEST_SYNCDSI_MASK          (uint8)((uint8)0x0Fu << PWMTEST_SYNCDSI_SHIFT)

    /* Sync all DSI inputs */
    #define PWMTEST_SYNCDSI_EN            (uint8)((uint8)0x0Fu << PWMTEST_SYNCDSI_SHIFT)


#else
    #define PWMTEST_STATUS                (*(reg8 *)   PWMTEST_PWMUDB_genblk8_stsreg__STATUS_REG )
    #define PWMTEST_STATUS_PTR            ((reg8 *)    PWMTEST_PWMUDB_genblk8_stsreg__STATUS_REG )
    #define PWMTEST_STATUS_MASK           (*(reg8 *)   PWMTEST_PWMUDB_genblk8_stsreg__MASK_REG)
    #define PWMTEST_STATUS_MASK_PTR       ((reg8 *)    PWMTEST_PWMUDB_genblk8_stsreg__MASK_REG)
    #define PWMTEST_STATUS_AUX_CTRL       (*(reg8 *)   PWMTEST_PWMUDB_genblk8_stsreg__STATUS_AUX_CTL_REG)
    #define PWMTEST_CONTROL               (*(reg8 *)   PWMTEST_PWMUDB_genblk1_ctrlreg__CONTROL_REG)
    #define PWMTEST_CONTROL_PTR           ((reg8 *)    PWMTEST_PWMUDB_genblk1_ctrlreg__CONTROL_REG)


    /***********************************
    *          Constants
    ***********************************/

    /* Control Register bit definitions */
    #define PWMTEST_CTRL_ENABLE_SHIFT      (0x07u)
    #define PWMTEST_CTRL_RESET_SHIFT       (0x06u)
    #define PWMTEST_CTRL_CMPMODE2_SHIFT    (0x03u)
    #define PWMTEST_CTRL_CMPMODE1_SHIFT    (0x00u)
    #define PWMTEST_CTRL_DEAD_TIME_SHIFT   (0x00u)   /* No Shift Needed for UDB block */
    
    /* Control Register Bit Masks */
    #define PWMTEST_CTRL_ENABLE            (uint8)((uint8)0x01u << PWMTEST_CTRL_ENABLE_SHIFT)
    #define PWMTEST_CTRL_RESET             (uint8)((uint8)0x01u << PWMTEST_CTRL_RESET_SHIFT)
    #define PWMTEST_CTRL_CMPMODE2_MASK     (uint8)((uint8)0x07u << PWMTEST_CTRL_CMPMODE2_SHIFT)
    #define PWMTEST_CTRL_CMPMODE1_MASK     (uint8)((uint8)0x07u << PWMTEST_CTRL_CMPMODE1_SHIFT)

    /* Status Register Bit Locations */
    #define PWMTEST_STATUS_KILL_SHIFT          (0x05u)
    #define PWMTEST_STATUS_FIFONEMPTY_SHIFT    (0x04u)
    #define PWMTEST_STATUS_FIFOFULL_SHIFT      (0x03u)
    #define PWMTEST_STATUS_TC_SHIFT            (0x02u)
    #define PWMTEST_STATUS_CMP2_SHIFT          (0x01u)
    #define PWMTEST_STATUS_CMP1_SHIFT          (0x00u)

    /* Status Register Interrupt Enable Bit Locations - UDB Status Interrupt Mask match Status Bit Locations*/
    #define PWMTEST_STATUS_KILL_INT_EN_MASK_SHIFT          (PWMTEST_STATUS_KILL_SHIFT)
    #define PWMTEST_STATUS_FIFONEMPTY_INT_EN_MASK_SHIFT    (PWMTEST_STATUS_FIFONEMPTY_SHIFT)
    #define PWMTEST_STATUS_FIFOFULL_INT_EN_MASK_SHIFT      (PWMTEST_STATUS_FIFOFULL_SHIFT)
    #define PWMTEST_STATUS_TC_INT_EN_MASK_SHIFT            (PWMTEST_STATUS_TC_SHIFT)
    #define PWMTEST_STATUS_CMP2_INT_EN_MASK_SHIFT          (PWMTEST_STATUS_CMP2_SHIFT)
    #define PWMTEST_STATUS_CMP1_INT_EN_MASK_SHIFT          (PWMTEST_STATUS_CMP1_SHIFT)

    /* Status Register Bit Masks */
    #define PWMTEST_STATUS_KILL            (uint8)((uint8)0x00u << PWMTEST_STATUS_KILL_SHIFT )
    #define PWMTEST_STATUS_FIFOFULL        (uint8)((uint8)0x01u << PWMTEST_STATUS_FIFOFULL_SHIFT)
    #define PWMTEST_STATUS_FIFONEMPTY      (uint8)((uint8)0x01u << PWMTEST_STATUS_FIFONEMPTY_SHIFT)
    #define PWMTEST_STATUS_TC              (uint8)((uint8)0x01u << PWMTEST_STATUS_TC_SHIFT)
    #define PWMTEST_STATUS_CMP2            (uint8)((uint8)0x01u << PWMTEST_STATUS_CMP2_SHIFT)
    #define PWMTEST_STATUS_CMP1            (uint8)((uint8)0x01u << PWMTEST_STATUS_CMP1_SHIFT)

    /* Status Register Interrupt Bit Masks  - UDB Status Interrupt Mask match Status Bit Locations */
    #define PWMTEST_STATUS_KILL_INT_EN_MASK            (PWMTEST_STATUS_KILL)
    #define PWMTEST_STATUS_FIFOFULL_INT_EN_MASK        (PWMTEST_STATUS_FIFOFULL)
    #define PWMTEST_STATUS_FIFONEMPTY_INT_EN_MASK      (PWMTEST_STATUS_FIFONEMPTY)
    #define PWMTEST_STATUS_TC_INT_EN_MASK              (PWMTEST_STATUS_TC)
    #define PWMTEST_STATUS_CMP2_INT_EN_MASK            (PWMTEST_STATUS_CMP2)
    #define PWMTEST_STATUS_CMP1_INT_EN_MASK            (PWMTEST_STATUS_CMP1)

    /* Datapath Auxillary Control Register bit definitions */
    #define PWMTEST_AUX_CTRL_FIFO0_CLR         (0x01u)
    #define PWMTEST_AUX_CTRL_FIFO1_CLR         (0x02u)
    #define PWMTEST_AUX_CTRL_FIFO0_LVL         (0x04u)
    #define PWMTEST_AUX_CTRL_FIFO1_LVL         (0x08u)
    #define PWMTEST_STATUS_ACTL_INT_EN_MASK    (0x10u) /* As defined for the ACTL Register */
#endif /* PWMTEST_UsingFixedFunction */

#endif  /* CY_PWM_PWMTEST_H */


/* [] END OF FILE */
