/*******************************************************************************
* File Name: VDAC_4_PM.c  
* Version 1.90
*
* Description:
*  This file provides the power management source code to API for the
*  VDAC8.  
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "VDAC_4.h"

static VDAC_4_backupStruct VDAC_4_backup;


/*******************************************************************************
* Function Name: VDAC_4_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void VDAC_4_SaveConfig(void) 
{
    if (!((VDAC_4_CR1 & VDAC_4_SRC_MASK) == VDAC_4_SRC_UDB))
    {
        VDAC_4_backup.data_value = VDAC_4_Data;
    }
}


/*******************************************************************************
* Function Name: VDAC_4_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
*******************************************************************************/
void VDAC_4_RestoreConfig(void) 
{
    if (!((VDAC_4_CR1 & VDAC_4_SRC_MASK) == VDAC_4_SRC_UDB))
    {
        if((VDAC_4_Strobe & VDAC_4_STRB_MASK) == VDAC_4_STRB_EN)
        {
            VDAC_4_Strobe &= (uint8)(~VDAC_4_STRB_MASK);
            VDAC_4_Data = VDAC_4_backup.data_value;
            VDAC_4_Strobe |= VDAC_4_STRB_EN;
        }
        else
        {
            VDAC_4_Data = VDAC_4_backup.data_value;
        }
    }
}


/*******************************************************************************
* Function Name: VDAC_4_Sleep
********************************************************************************
* Summary:
*  Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  VDAC_4_backup.enableState:  Is modified depending on the enable 
*  state  of the block before entering sleep mode.
*
*******************************************************************************/
void VDAC_4_Sleep(void) 
{
    /* Save VDAC8's enable state */    
    if(VDAC_4_ACT_PWR_EN == (VDAC_4_PWRMGR & VDAC_4_ACT_PWR_EN))
    {
        /* VDAC8 is enabled */
        VDAC_4_backup.enableState = 1u;
    }
    else
    {
        /* VDAC8 is disabled */
        VDAC_4_backup.enableState = 0u;
    }
    
    VDAC_4_Stop();
    VDAC_4_SaveConfig();
}


/*******************************************************************************
* Function Name: VDAC_4_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  VDAC_4_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void VDAC_4_Wakeup(void) 
{
    VDAC_4_RestoreConfig();
    
    if(VDAC_4_backup.enableState == 1u)
    {
        /* Enable VDAC8's operation */
        VDAC_4_Enable();

        /* Restore the data register */
        VDAC_4_SetValue(VDAC_4_Data);
    } /* Do nothing if VDAC8 was disabled before */    
}


/* [] END OF FILE */
